/*
 * AnimalAnim.qml
 * Animal view with visual transition
 *
 * VCC VisualCare Consult
 *
 * Created by Yannick GRANGER, Medi-Productions
 * ygranger@mediproductions.com
 * Copyright 2014 Medi-Productions. All rights reserved
 *
 */

import QtQuick 2.7

Item {
    height: parent.height
    width: height * 572 / 644

    Image {
        id: whole1
        anchors.centerIn: parent
        anchors.fill: parent
        fillMode: Image.PreserveAspectFit
        opacity: 1
        source: "../../img/animals/" + _subpath + "/" + _whole1
    }
    Image {
        id: skinArriere
        anchors.centerIn: parent
        anchors.fill: parent
        fillMode: Image.PreserveAspectFit
        opacity: 0
        source: "../../img/animals/" + _subpath + "/skin/" + _skin
    }
    Image {
        id: skelArriere
        anchors.centerIn: parent
        anchors.fill: parent
        fillMode: Image.PreserveAspectFit
        opacity: 0
        source: _subpath != "" ? "../../img/animals/" + _subpath + "/skel/" + _skelBack : ""
    }
    Image {
        id: organGlow
        anchors.centerIn: parent
        anchors.fill: parent
        fillMode: Image.PreserveAspectFit
        opacity: 0
        source: ""
    }
    Image {
        id: organ
        anchors.centerIn: parent
        anchors.fill: parent
        fillMode: Image.PreserveAspectFit
        opacity: 0
        source: ""
    }
    Image {
        id: skelFront
        anchors.centerIn: parent
        anchors.fill: parent
        fillMode: Image.PreserveAspectFit
        opacity: 0
        source: "../../img/animals/" + _subpath + "/skel/" + _skelFront
    }
    function setOrgan(glow, normal) {
        organ.source = "../../img/animals/" + _subpath + "/organ/" + normal
        organGlow.source = "../../img/animals/" + _subpath + "/organ/" + glow
        this.animate()
    }

    function animate() {
        organ.opacity = 0
        animateOpacity1.start()
        animateOpacity2.start()
        animateOpacity3.start()
        animateOpacity4.start()
        animation.start()
    }

    PropertyAnimation {
        id: animateOpacity1
        target: whole1
        properties: "opacity"
        to: 0
        duration: 200
    }
    PropertyAnimation {
        id: animateOpacity2
        target: skinArriere
        properties: "opacity"
        to: 1
        duration: 200
    }
    PropertyAnimation {
        id: animateOpacity3
        target: skelArriere
        properties: "opacity"
        to: 1
        duration: 200
    }
    PropertyAnimation {
        id: animateOpacity4
        target: skelFront
        properties: "opacity"
        to: 1
        duration: 200
    }

    SequentialAnimation {
        id: animation
        PropertyAnimation {
            id: animateOpacity5
            target: organGlow
            properties: "opacity"
            to: 1
            duration: 200
        }
        PropertyAnimation {
            id: animateOpacity6
            target: organGlow
            properties: "opacity"
            to: 0
            duration: 200
        }
        PropertyAnimation {
            id: animateOpacity7
            target: organ
            properties: "opacity"
            to: 1
            duration: 300
        }
    }
}
