import QtQuick 2.7
import QtQuick.Controls 2.1
import QtMultimedia 5.8
import QtQuick.Dialogs 1.2
import QtQuick.Layouts 1.2

Item {
    id: myMediaPlayerRect
    property string source: ""
    property bool loop: false
    property int playbackState
    property int position
    property int duration

    signal seek(int _position)

    /* signal to pass to component */
    signal play
    signal pause
    signal stop
    signal videoEnded

    Timer {
        /* only used for mali gpu */
        id: httpTimer
        interval: 400
        repeat: false
        running: false
        onTriggered: {
            mediaP.source = vcc.mediaHost + myMediaPlayerRect.source
            mediaP.play()
        }
    }

    onSourceChanged: {
        if ((source.indexOf(".mp4") != -1)) {
            mediaPOutput.visible
                    = true //ios fix for mediaplayer stop state don't hide automatically
            image.source = ""
            if (vcc.useLocalHttpServer) {
                mediaP.source = ""
                //console.log("streamed video => ",vcc.mediaHost+source)
                httpTimer.start()
            } else {
                //console.log("Mali test debug : readed video => ",vcc.mediaHost+source)
                mediaP.source = vcc.mediaHost + source
                mediaP.play()
            }
        } else if ((source.indexOf(".jpg") != -1)) {
            mediaPOutput.visible
                    = false //ios fix for mediaplayer stop state don't hide automatically
            mediaP.source = ""
            image.source = "file:///"+vcc.getVCCFolder()+"/data/" + source
        } else {
            mediaPOutput.visible
                    = false //ios fix for mediaplayer stop state don't hide automatically
            mediaP.source = ""
            image.source = ""
        }
    }

    function displayTime(valueInMS) {
        var _minutes = Math.floor(valueInMS / 1000 / 60)
        var _seconds = Math.floor(valueInMS / 1000 % 60)
        var _result = ""
        _result += _minutes + ":"
        if (_seconds < 10)
            _result += "0"
        _result += _seconds
        return _result
    }

    Column {
        id: column1
        anchors.fill: parent
        width: parent.width
        height: width / 4 * 3 + Math.floor(width * 0.06)
        property alias toolbarHeight: toolbar.height
        Rectangle {
            width: parent.width
            height: width / 4 * 3
            color: "black"
            //            Image{
            //                anchors.centerIn: parent
            //                width:217*app.ratio
            //                height:190*app.ratio
            //                source:"../../img/logo.png"
            //            }
            Image {
                id: image
                fillMode: Image.PreserveAspectFit
                width: myMediaPlayerRect.width
                height: (currentOS !== "ios"
                         && videoArea.state === "maximized") ? app.height : parent.height
                source: ""
                onStatusChanged: if (image.status == Image.Error)
                                     console.log("[QML MediaView] problem with image ",
                                                 source)
            }
            VideoOutput {
                id: mediaPOutput
                width: myMediaPlayerRect.width
                height: (currentOS !== "ios"
                         && videoArea.state === "maximized") ? app.height : parent.height
                fillMode: VideoOutput.PreserveAspectFit
                source: mediaP
            }
        }
        Rectangle {
            id: toolbar
            width: parent.width
            height: Math.floor(width * 0.06)
            color: "#DDDDDD"
            RowLayout {
                anchors.fill: parent
                anchors.rightMargin: 10 * app.ratio
                anchors.leftMargin: 30 * app.ratio
                spacing: width * 0.03
                Item {
                    id: iconItem
                    Layout.fillHeight: true
                    Layout.preferredWidth: parent.height
                    visible: (source.indexOf(".mp4") != -1)
                    Image {
                        anchors.centerIn: parent
                        id: iconImage
                        width: 20 * app.ratio
                        height: 20 * app.ratio
                        source: mediaP.playbackState == MediaPlayer.PlayingState ? "../../img/icones/mediaPause.png" : "../../img/icones/mediaPlay.png"
                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                if (mediaP.playbackState == MediaPlayer.PlayingState)
                                    mediaP.pause()
                                else if (mediaP.playbackState == MediaPlayer.PlayingState)
                                    mediaP.play()
                                else //ios fix for mediaplayer stop state don't hide automatically =>> when bug fixed delete it and last else if test
                                {
                                    mediaP.source = ""
                                    mediaP.source = vcc.mediaHost + source
                                    mediaP.play()
                                }
                            }
                        }
                    }
                }
                Item {
                    id: positionItem
                    Layout.fillHeight: true
                    Layout.preferredWidth: positionText.width
                    Text {
                        anchors.centerIn: parent
                        id: positionText
                        text: displayTime(slider.value)
                    }
                }
                Slider {
                    id: slider
                    Layout.fillHeight: true
                    Layout.fillWidth: true
                    value: (app._fileType === "IMG"
                            || app._fileType === "") ? 0 : mediaP.position
                    to: (app._fileType === "IMG"
                                   || app._fileType === "") ? 0 : mediaP.duration
                    onValueChanged: if (pressed)
                                        mediaP.seek(value)
                }
                Item {
                    id: durationItem
                    Layout.fillHeight: true
                    Layout.preferredWidth: durationText.width
                    Text {
                        anchors.centerIn: parent
                        id: durationText
                        text: slider.to == 0 ? "-:-" : displayTime(slider.to)
                    }
                }
                Item {
                    id: checkMd5IconItem
                    Layout.fillHeight: true
                    Layout.preferredWidth: parent.height
                    visible: source!==""
                    Image {
                        anchors.centerIn: parent
                        id: checkMd5Icon
                        width: 20 * app.ratio
                        height: 20 * app.ratio
                        source: "../../img/icones/icon-m-glass.png"
                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                if(vcc.online){
                                    console.log('check file ', source)
                                    app.checkMd5ForFile(source)
                                }else{
                                    notOnline.visible=true
                                }
                            }
                        }
                    }
                    Connections{
                        target: vcc
                        onMd5Response: {
                            if (_filename === source){
                                console.log('file ',_filename,' is ok ? ',_isValid)
                                fileVerificationMessage.isValid = _isValid
                                fileVerificationMessage.visible = true
                            }
                        }
                    }
                }
            }
        }
    }
    MediaPlayer {
        id: mediaP
        onPlaybackStateChanged: myMediaPlayerRect.playbackState = mediaP.playbackState
        onDurationChanged: myMediaPlayerRect.duration = mediaP.duration
        onStopped: myMediaPlayerRect.videoEnded()
        loops: myMediaPlayerRect.loop ? MediaPlayer.Infinite : 1
    }
    Timer {
        /* better slider move */
        id: sliderTimer
        interval: 200
        running: videoArea.state != "maximized"
        repeat: true
        triggeredOnStart: true
        onTriggered: slider.value = mediaP.position
    }

    onPlay: {
        //ios fix for mediaplayer stop state don't hide automatically =>> when bug fixed replace it with "onPlay:mediaP.play()"
        if (mediaP.playbackState == MediaPlayer.PausedState)
            mediaP.play()
        else {
            mediaP.source = vcc.mediaHost + source
            mediaP.play()
        }
    }

    onPause: mediaP.pause()
    onStop: mediaP.stop()
    onSeek: mediaP.seek(_position)

    MessageDialog{
        id:fileVerificationMessage
        property bool isValid
        title: qsTr("Vérification du fichier")
        text: isValid ? qsTr("Le fichier est à jour") : qsTr("Le fichier n'est pas à jour. Il va être téléchargé prochainement.")
        standardButtons: StandardButton.Ok
    }
}
