import QtQuick 2.7
import QtQuick.Window 2.0
import QtQuick.Layouts 1.1
import QtQuick.Controls 2.1
import QtQuick.Dialogs 1.2

import "./"

Item {
    id: objRoot
    objectName: "objRoot"
    property alias model: listview.model
    property string title: "" //to create first row for bookmarks/playlist/...
    property int currentItem
    // only for playlist
    property string fileWeAreWaitingFor: ""
    property bool clickOnANewMedia: false /* for playlist only*/

    signal needRefresh

    function launchNextItem() /* only for playlist */
    {
        if (!clickOnANewMedia) {
            console.log("[QML Tree(playlist)] launch next video", currentItem)
            var _nextItem
            _nextItem = currentItem + 1
            if (_nextItem === listview.count)
                _nextItem = 0
            console.log("[QML Tree] ",
                        playlist[_nextItem].fileOK) //TODO DELETE LINE
            while (playlist[_nextItem].fileOK !== true) {
                console.log("[QML Tree(playlist)] file not available")
                _nextItem = _nextItem + 1
                if (_nextItem === listview.count)
                    _nextItem = 0
            }
            mediaView.selectOutput(playlist[_nextItem].fileName,
                                   playlist[_nextItem].loop,
                                   playlist[_nextItem].fileOK)
            app._filename = playlist[_nextItem].fileName
            currentItem = _nextItem
        }
        clickOnANewMedia = false
    }
    RectGrad {
        id: background
        angle: -2
        position1: 0.3
        position2: 0.7
        anchors.fill: parent
        anchors.topMargin: app.ratioH * 45
        color1: "#fdfdfb"
        color2: "#d7e2da"
    }
    Item{
        id:editedItem
        property string filename
        property int index

        function reset(){
            filename = ""
            index = -1
        }
        Component.onCompleted: reset()
    }

    Component {
        id: objRecursiveDelegate
        Column {
            id: objRecursiveColumn
            property bool populated: false // populate subnode delegates only one time
            objectName: "objRecursiveColumn"
            function reduce() {
                if (objRepeater.count > 0) {
                    for (var i = 0; i < objRepeater.count; ++i) {
                        if (objRepeater.itemAt(i).objectName === "objRecursiveColumn")
                            objRepeater.itemAt(i).reduce()
                    }
                }
                for (var j = 0; j < this.children.length; ++j) {
                    if (this.children[j].objectName !== "objMouseArea")
                        this.children[j].visible = false
                }
            }
            function develop() {
                for (var j = 0; j < this.children.length; ++j)
                    this.children[j].visible = true
            }
            function populate() {
                if (model.subNodeSize > 0 && !populated) {
                    for (var i = 0; i < model.subNodeSize; ++i) {
                        var item
                        if (model.level < 1) {
                            item = model.subNode[i] //first subnode as array
                        } else {
                            item = model.subNode.get(i) //after subnode as listmodel
                        }
                        model2.append({
                                          name: item.name,
                                          subNode: item.subNode,
                                          rank: item.rank,
                                          subNodeSize: item.subNodeSize,
                                          fileName: item.fileName,
                                          type: item.type,
                                          loop: item.loop,
                                          newMedia: item.newMedia,
                                          free: item.free,
                                          dateAndTime: item.dateAndTime,
                                          fileOK: item.fileOK,
                                          defaultFile: item.defaultFile,
                                          linkedUrl: item.linkedUrl
                                      })
                    }
                    populated = true
                }
                this.reduce()
            }
            MouseArea {
                id: objMouseArea
                objectName: "objMouseArea"
                width: objDisplayRowRect.width
                height: objDisplayRowRect.height
                onClicked: {
                    //console.log("[QML Tree] state :",coloredRect.state)
                    //                    objRecursiveColumn.populate()
                    //                    objRoot.parent.clearWindow()
                    if (model.fileName !== "") {
                        if (app._filename !== "")
                            /* for playlist only*/
                            clickOnANewMedia = true
                        //console.log("[QML Tree] media Selected :",model.fileName)
                        objRoot.currentItem = model.index /* for playlist only */
                        if (/*!vcc.connected && */ !model.free) {
                            objRoot.parent.clearSource()
                            notFreeContent.open()
                        } else {
                            app._filename = model.fileName
                            app._fileTitle = model.name
                            app._fileType = model.type
                            /* fileOK is not updated when download is done when this organ is selected  so we use a property justDownload*/
                            app._fileOk = model.fileOK
                                    || objFileOkOrNot.justDownload
                            if (model.fileOK || !notOkImg.visible) {
                                /* send stat only if video is visible */
                                app.watch(model.fileName, model.name)
                            } else {
                                objRoot.parent.clearSource()
                                app.downloadNow(model.fileName, "watching")
                            }
                            /* fileOK is not updated when download is done when this organ is selected  so we use a property justDownload*/
                            app._linkedUrl = model.linkedUrl
                            console.log("app._linkedUrl = ", model.linkedUrl)
                            objRoot.parent.selectOutput(
                                        model.fileName, model.loop, model.fileOK
                                        || objFileOkOrNot.justDownload)
                        }
                    } else {
                        objRecursiveColumn.populate()
                        objRoot.parent.clearWindow()
                        for (var i = 0; i < parent.parent.children.length; ++i) {
                            if (parent.parent.children[i].objectName === "objRecursiveColumn")
                                parent.parent.children[i].reduce()
                        }
                        parent.develop()
                        if (model.defaultFile !== "") {

                            /* defaut section file */
                            //console.log("[QML tree] default file ", model.defaultFile)
                            app._linkedUrl = model.linkedUrl
                            console.log("[QML tree] app._linkedUrl = ", model.linkedUrl)
                            objRoot.parent.selectOutput(model.defaultFile,
                                                        false, true)
                        }
                    }
                }
                Item {
                    id: objDisplayRowRect
                    height: app.ratioH * 35
                    width: objRoot.width
                    RectGrad {
                        id: coloredRect

                        angle: -2
                        position1: 0.3
                        position2: 0.7
                        anchors.fill: parent
                        state: model.fileName === "" ? "rang" + (model.rank + 1) : (model.fileName === app._filename ? "selectedMedia" : "media")
                        states: [
                            State {
                                name: "rang1"
                                PropertyChanges {
                                    target: coloredRect
                                    color1: "#004857"
                                }
                                PropertyChanges {
                                    target: coloredRect
                                    color2: "#001624"
                                }
                                PropertyChanges {
                                    target: objNodeName
                                    color: "white"
                                }
                                PropertyChanges {
                                    target: indentation
                                    width: 0
                                }
                                //                                PropertyChanges{target: coloredRect; anchors.leftMargin:app.ratioH *1}
                            },
                            State {
                                name: "rang2"
                                PropertyChanges {
                                    target: coloredRect
                                    color1: "#0270a1"
                                }
                                PropertyChanges {
                                    target: coloredRect
                                    color2: "#003b81"
                                }
                                PropertyChanges {
                                    target: objNodeName
                                    color: "white"
                                }
                                PropertyChanges {
                                    target: indentation
                                    width: 3.5 * app.ratioH
                                }
                                //                                PropertyChanges{target: coloredRect; anchors.leftMargin:app.ratioH *1}
                            },
                            State {
                                name: "rang3"
                                PropertyChanges {
                                    target: coloredRect
                                    color1: "#00c0d7"
                                }
                                PropertyChanges {
                                    target: coloredRect
                                    color2: "#008eba"
                                }
                                PropertyChanges {
                                    target: objNodeName
                                    color: "white"
                                }
                                PropertyChanges {
                                    target: indentation
                                    width: 14 * app.ratioH
                                }
                                //                                PropertyChanges{target: coloredRect; anchors.leftMargin:app.ratioH *1}
                            },
                            State {
                                name: "media"
                                PropertyChanges {
                                    target: coloredRect
                                    color1: "#fdfdfb"
                                }
                                PropertyChanges {
                                    target: coloredRect
                                    color2: "#d7e2da"
                                }
                                PropertyChanges {
                                    target: objNodeName
                                    color: /*!vcc.connected &&*/ !model.free ? "#DDDDDD" : "#4793a1"
                                }
                                PropertyChanges {
                                    target: indentation
                                    width: 0
                                }
                                //                                PropertyChanges{target: coloredRect; anchors.leftMargin:app.ratioH *0}
                            },
                            State {
                                name: "selectedMedia"
                                PropertyChanges {
                                    target: coloredRect
                                    color1: "#85a1a5"
                                }
                                PropertyChanges {
                                    target: coloredRect
                                    color2: "#577377"
                                }
                                PropertyChanges {
                                    target: objNodeName
                                    color: "white"
                                }
                                PropertyChanges {
                                    target: indentation
                                    width: 0
                                }
                                PropertyChanges {
                                    target: coloredRect
                                    anchors.leftMargin: app.ratioH * 20
                                }
                            }
                        ]
                    }
                    Row {
                        anchors.left: parent.left
                        anchors.leftMargin: app.ratioH * 5
                        anchors.verticalCenter: parent.verticalCenter
                        spacing: app.ratioH * 5
                        Item {
                            id: icone
                            height: parent.parent.height * 0.8
                            width: typeImg.source == "" ? 0 : height
                            Image {
                                id: typeImg
                                anchors.fill: parent
                                source: model.type !== "" ? "../../img/mediaType/"  + model.type + ".png" : ""
                            }
                            Image {
                                id: newImg
                                anchors.fill: parent
                                source: model.newMedia ? "../../img/mediaType/Icone-transparent-NEW-version-1.png" : ""
                            }
                        }
                        Item {
                            id: indentation
                            height: parent.height
                        }
//                        Rectangle{
//                            color:"red"

                        Item{
                            id: textComponent
                            property bool editable : false
                            property string text : model.name
                            anchors.verticalCenter: parent.verticalCenter
                            width : objNodeEditableName.width
                            height : parent.height
                            Text {
                                id: objNodeName
                                visible: !parent.editable
                                anchors.verticalCenter: parent.verticalCenter
                                text: parent.text //"texte beaucoup trop long pour être affiché correctement dans la fenetre"
                                font {
                                    family: localFont.name
                                    bold: false
                                    pixelSize: app.ratioH * 12
                                }
                                verticalAlignment: Text.AlignVCenter
                            }
                            TextField{
                                id: objNodeEditableName
                                visible: parent.editable
                                anchors.verticalCenter: parent.verticalCenter
                                text: parent.text //"texte beaucoup trop long pour être affiché correctement dans la fenetre"
                                font {
                                    family: localFont.name
                                    bold: false
                                    pixelSize: app.ratioH * 12
                                }
                                verticalAlignment: Text.AlignVCenter
                                onTextChanged:parent.text = text
                                onAccepted: {
                                    parent.editable = false
                                    if (objRoot.title === qsTr("FAVORIS")){
                                        console.log('[QML Tree] update for bookmarks')
                                        app.renameStoredItem(model.fileName, text, "bookmarks")
                                        editedItem.reset()
                                    }
                                    else if (objRoot.title === qsTr("PLAYLIST")){
                                        console.log('[QML Tree] update for playlist')
                                        app.renameStoredItem(model.fileName, text, "playlist")
                                        editedItem.reset()
                                    }
                                }
                            }
                        }
                    }
                    Item {
                        id: objFileOkOrNot
                        height: parent.height * 0.5
                        width: height
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.right: editButton.left
                        anchors.rightMargin: app.ratioH * 10
                        visible: model.fileName !== ""
                        property bool justDownload: false
                        Image {
                            id: notOkImg
                            anchors.fill: parent
                            source: model.fileOK
                                    === false ? "../../img/mediaType/dot_orange.png" : ""
                        }
                        Image {
                            property bool blinkState: true
                            id: blinkImage
                            anchors.fill: parent
                            visible: blinkTimer.running && blinkState
                            source: "../../img/mediaType/dot_vert.png"
                            Timer {
                                id: blinkTimer
                                repeat: true
                                running: coloredRect.state === "selectedMedia"
                                         && model.fileOK === false
                                         && model.fileName !== vcc.downloadingMedia
                                interval: 400
                                onTriggered: parent.blinkState = !parent.blinkState
                            }
                        }
                        Image {
                            id: downloadingImg
                            anchors.fill: parent
                            source: model.fileName === vcc.downloadingMedia ? "../../img/mediaType/dot_vert.png" : ""
                            onSourceChanged: {
                                if (source != "") {
                                    notOkImg.visible = false
                                } else {
                                    blinkImage.visible = false
                                    objFileOkOrNot.justDownload = true
                                    if (app._filename === model.fileName) {
                                        console.log("[QML Tree] now downloaded so launch media")
                                        app.watch(app._filename, app._fileTitle)
                                        app._fileOk = true

                                        /* fileOK is not updated when download is done when this organ is selected  so we use a property justDownload*/
                                        app._linkedUrl = model.linkedUrl
                                        console.log("[QML Tree] app._linkedUrl = ",
                                                    model.url)
                                        objRoot.parent.selectOutput(
                                                    app._filename, model.loop,
                                                    model.fileOK
                                                    || objFileOkOrNot.justDownload)
                                    }
                                }
                            }
                        }
                    }
                    Item {
                        id: editButton
                        height: parent.height
                        width: visible ? height * 1.2 : 0
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.right: parent.right
                        visible: (objRoot.title === qsTr("FAVORIS")
                                 || objRoot.title === qsTr("PLAYLIST"))
                                && !(vccContract_Short==="PHN3D"
                                     || vccContract_Short==="REDBANK")
                                && (editedItem.index === -1 || editedItem.index === index)
                        Image {
                            anchors.right: parent.right
                            anchors.rightMargin: app.ratioH * 10
                            anchors.verticalCenter: parent.verticalCenter
                            width: parent.height * 0.6
                            fillMode: Image.PreserveAspectFit
                            source: textComponent.editable == true ? "../../img/icones/icon-trash.png" : "../../img/icones/icon-edit.png"
                        }
                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                console.log("clicked ?")
                                if (!vcc.online){
                                    notOnline.visible = true
                                    return;
                                }
                                if (textComponent.editable){//click on trash
                                    console.log("[QML Tree] delete item in ",objRoot.title," ???")
                                    removeAlert.visible = true
                                }else{ //click on edit
                                    editedItem.filename = model.fileName
                                    editedItem.index = index
                                    textComponent.editable=true
                                }
                            }
                        }
                    }
                }
            }
            Repeater {
                id: objRepeater
                objectName: "objRepeater"
                delegate: objRecursiveDelegate
                model: model2
            }
            ListModel {
                id: model2
            }
        }
    }
    ColumnLayout {
        objectName: "objColLayout"
        anchors.fill: parent
        Item {
            height: /*objRoot.title==""? 0 : */ app.ratioH * 35
            width: objRoot.width
            Text {
                color: "white"
                anchors.left: parent.left
                anchors.verticalCenter: parent.verticalCenter
                text: (objRoot.title != "") ? objRoot.title : qsTr("MENU")
                font {
                    family: localFont.name
                    bold: true
                    pixelSize: app.ratioH * 20
                }
                verticalAlignment: Text.AlignVCenter
            }
        }
        ListView {
            id: listview
            Connections {
                target: vccData
                onSuborganUpdateChanged: {
                    //console.log("[QML Tree] on suborgans updated ---------------load media organ")
                    //console.log("[QML Tree] on suborgans updated ---------------dfaultImage",defaultImage)
                    listview.model = subOrgans
                    if (defaultImage !== "") {

                        /* defaut menu file */
                        //console.log("[QML Tree] on suborgans updated ---------------dfaultImage",defaultImage)
                        objRoot.parent.selectOutput(defaultImage,false, true)
                    }

                }
            }
            PropertyAnimation {
                id: arbreFadeIn
                target: listview
                property: "opacity"
                to: 1
                duration: 400
            }
            onModelChanged: arbreFadeIn.start()
            opacity: 0
            objectName: "objListView"
            Layout.fillHeight: true
            Layout.fillWidth: true
            delegate: objRecursiveDelegate
        }
        Connections {
            target: vcc
            onBookmarksCountChanged: {
                if (mediaView.stackName == "bookmarks.qml") {
                    listview.model = bookmarks
                    objRoot.needRefresh()
                } else if (mediaView.stackName == "playlist.qml") {
                    listview.model = playlist
                    objRoot.needRefresh()
                }
            }
        }
    }
    MessageDialog {
        id: removeAlert
        title: ""
        text: qsTr("Voulez vous vraiment supprimer ce contenu ?")
        standardButtons: StandardButton.Yes | StandardButton.No

        onYes: {
            console.log("[QML Tree] delete item in ",objRoot.title," YES")
            if (objRoot.title === qsTr("FAVORIS"))
                app.deleteStoredItem(editedItem.filename, "bookmarks")
            else if (objRoot.title === qsTr("PLAYLIST"))
                app.deleteStoredItem(editedItem.filename, "playlist")
            editedItem.reset()
            visible = false
        }
    }
}
