/*
 * myAccountLogin.qml
 * login window
 *
 * VCC VisualCare Consult
 *
 * Created by Yannick GRANGER, Medi-Productions
 * ygranger@mediproductions.com
 * Copyright 2014 Medi-Productions. All rights reserved
 *
 */

import QtQuick 2.7
import QtQuick.Controls 2.1
//import QtQuick.Controls.Styles 1.4
import QtQuick.Dialogs 1.2
import QtQuick.Layouts 1.1

Rectangle {
    id: loginView
    property string selectedContract: "" /* cleaned if user change the email*/
    width: app.width
    height: app.height
    color: "#55000000"
    Connections {
        target: vcc
        onAlreadyConnected: loading.visible = false
        onUserNotFound: loading.visible = false
        onUserWithoutOrder: loading.visible = false
        onConnectedChanged: {
            loading.visible = false
            stackView.pop(null)
        }
        onContractListReceived: {
            for (var i = 0; i < _contractList.length; i++) {
                console.log("[QML myAccountLogin] receive contract list", _contractList[i])
            }
            if (_contractList.length === 1) {
                loginView.selectedContract = _contractList[0]
                loginView.callLogin()
            } else if (_contractList.length > 1) {
                loginView.selectedContract = _contractList[0]
                listview.model = _contractList
                loading.visible = false
            } else {
                loading.visible = false
                console.log("no contract")
            }
        }
    }

    function callLogin() {
        Qt.inputMethod.hide()
        var re = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/
        if (!re.test(login.text))
            wrongLogin.open()
        else if (vcc.online) {
            loading.visible = true
            if (loginView.selectedContract != "") {
                console.log("[QML myAccountLogin] login to ",
                            loginView.selectedContract)
                listview.model = undefined
                //stackView.pop(null)
                doLogin(login.text, password.text, loginView.selectedContract)
            } else
                getContractList(login.text)
        } else
            notOnline.visible = true
    }

    MouseArea {
        //to cancel mousearea under this qml
        anchors.fill: parent
    }
    Rectangle {
        id: window
        anchors.centerIn: parent
        width: loginView.height * 0.9
        height: parent.height * 0.8
        color: "#e4eded"
        border.color: "#545454"
        border.width: app.ratioH * 2

        Rectangle {
            id: titleArea
            anchors.top: parent.top
            anchors.horizontalCenter: parent.horizontalCenter
            width: parent.width
            height: loginView.height * 0.05
            color: "#ffffff"
            border.width: app.ratioH * 1
            Rectangle {
                id: back
                anchors.top: parent.top
                anchors.bottom: parent.bottom
                anchors.left: parent.left
                width: backText.paintedWidth * 2
                color: "#00000000"
                Text {
                    id: backText
                    anchors.centerIn: parent
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                    text: qsTr("Retour")
                    color: "#0937b7"
                    font.pixelSize: userWindowLoader.fontText
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        Qt.inputMethod.hide()
                        userWindowLoader.source = ""
                    }
                }
            }
            Text {
                id: title
                anchors.centerIn: parent
                text: qsTr("Mon compte")
                font.bold: true
                font.pixelSize: userWindowLoader.fontText
                color: "black"
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            }
            Rectangle {
                id: ok
                anchors.top: parent.top
                anchors.bottom: parent.bottom
                anchors.right: parent.right
                width: okText.paintedWidth * 4
                color: "#00000000"
                Text {
                    id: okText
                    anchors.centerIn: parent
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                    text: qsTr("Ok")
                    color: "#0937b7"
                    font.pixelSize: userWindowLoader.fontText
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        Qt.inputMethod.hide()
                        if (login.text == "" || password.text == "")
                            emptyContent.open()
                        else
                            loginView.callLogin()
                    }
                }
            }
        }

        Column {
            id: column1
            anchors.top: titleArea.bottom
            anchors.topMargin: app.ratioH * 20
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            anchors.left: parent.left
            spacing: app.ratioH * 40

            Text {
                id: queryText
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width * 0.75
                color: "#0038b6"
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                font.pixelSize: userWindowLoader.fontText
                Component.onCompleted: {
                    if (vccContract_Short === "IDEXX") {
                        text = qsTr("Commencez dès aujourd'hui! \nCette application requiert que vous soyez connecté. Si vous avez besoin d'informations complémentaires, \nn'hésitez pas à contacter votre représentant IDEXX Pet Health Network® Communication.")
                    } else if (vccContract_Short === "VCC") {
                        text = qsTr("<html>Veuillez entrer vos identifiants de connexion. <br>Pour plus d'informations, visitez le site <br><a href=\"http://www.mediproductions.com/ordernow\">www.mediproductions.com/ordernow</a></html>")
                    } else {
                        text = qsTr("Veuillez entrer vos identifiants de connexion")
                    }
                }
                onLinkActivated: Qt.openUrlExternally(link)
            }

            Grid {
                id: loginPassword
                anchors.horizontalCenter: parent.horizontalCenter
                columns: 2
                rows: 3
                spacing: 0
                Rectangle {
                    id: loginTextRect
                    height: loginText.paintedHeight * 1.4
                    radius: app.ratioH * 2
                    border.color: "#999"
                    border.width: app.ratioH * 1
                    width: (loginText.paintedWidth < passwordText.paintedWidth ? passwordText.paintedWidth : loginText.paintedWidth) * 1.1
                    Text {
                        id: loginText
                        text: qsTr("Identifiant")
                        color: "#0038b6"
                        anchors.centerIn: parent
                        font.pixelSize: userWindowLoader.fontText
                    }
                }
                TextField {
                    id: login
                    color: "black"
                    background: Rectangle {
                        radius: app.ratioH * 2
                        border.color: "#999"
                        border.width: app.ratioH * 1
                    }
                    font.pixelSize: userWindowLoader.fontText
                    height: loginTextRect.height
                    width: window.width * 0.5
                    placeholderText: qsTr("votre adresse email")
                    inputMethodHints: Qt.ImhEmailCharactersOnly | Qt.ImhNoAutoUppercase
                    text: vcc.oldLoginId
                    onTextChanged: {
                        /* clear selected contract if one is selected */
                        loginView.selectedContract = ""
                    }
                    Keys.onReturnPressed: {
                        if (password.text != "" && login.text != "") {
                            loginView.callLogin()
                        } else if (login.text != "")
                            password.forceActiveFocus()
                    }
                }

                Item {
                    //manual spacing
                    height: login.height
                    width: 10
                }
                Item {
                    //manual spacing
                    height: login.height
                    width: 10
                }

                Rectangle {
                    height: loginTextRect.height
                    radius: app.ratioH * 2
                    border.color: "#999"
                    border.width: app.ratioH * 1
                    width: (loginText.paintedWidth < passwordText.paintedWidth ? passwordText.paintedWidth : loginText.paintedWidth) * 1.1
                    Text {
                        id: passwordText
                        text: qsTr("Mot de passe")
                        anchors.centerIn: parent
                        color: "#0038b6"
                        font.pixelSize: userWindowLoader.fontText
                    }
                }
                TextField {
                    id: password
                    color: "black"
                    background: Rectangle {
                        radius: app.ratioH * 2
                        border.color: "#999"
                        border.width: app.ratioH * 1
                    }
                    /* bugfix for android tablet */
                    font.pixelSize: ((currentOS === "android")
                                     && text != "") ? userWindowLoader.fontText
                                                      * 0.6 : userWindowLoader.fontText
                    /*font.pixelSize: userWindowLoader.fontText */
                    /* bugfix end*/
                    echoMode: TextInput.Password
                    width: login.width
                    height: loginTextRect.height
                    placeholderText: qsTr("votre mot de passe")
                    text: vcc.password
                    Keys.onReturnPressed: {
                        if (password.text != "" && login.text != "") {
                            loginView.callLogin()
                        } else if (password.text != "")
                            login.forceActiveFocus()
                    }
                }
            }
            Component {
                id: contactDelegate
                Item {
                    Text {
                        text: modelData
                        anchors.centerIn: parent
                    }
                    width: listview.width
                    height: listview.height / listview.count
                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            listview.currentIndex = index
                            loginView.selectedContract = modelData
                        }
                    }
                }
            }

            ListView {
                id: listview
                width: parent.width * 0.75
                height: parent.height * 0.2
                anchors.horizontalCenter: parent.horizontalCenter
                delegate: contactDelegate
                highlight: Rectangle {
                    color: "lightsteelblue"
                    radius: 5
                }
                focus: true
            }
            Button {
                id: button
                anchors.horizontalCenter: parent.horizontalCenter
                text: qsTr("LOGIN")
                onClicked: {
                    loginView.callLogin()
                }
            }
        }
        AnimatedImage {
            id: loading
            anchors.centerIn: parent
            width: parent.height * 0.1
            height: parent.height * 0.1
            source: "../../img/loading.gif"
            visible: false
        }
    }

    MessageDialog {
        id: wrongLogin
        title: ""
        text: qsTr("Le login n'est pas valide")
        standardButtons: StandardButton.Ok
    }
}
