/*
 * myAccountPref.qml
 * preferences window
 *
 * VCC VisualCare Consult
 *
 * Created by Yannick GRANGER, Medi-Productions
 * ygranger@mediproductions.com
 * Copyright 2014 Medi-Productions. All rights reserved
 *
 */

import QtQuick 2.7
import QtQuick.Dialogs 1.2
import QtQuick.Controls 2.1

Rectangle {
    id: preferencesView
    width: app.width
    height: app.height
    color: "#55000000"
    MouseArea {
        //to cancel mousearea under this qml
        anchors.fill: parent
    }
    Rectangle {
        id: window
        anchors.centerIn: parent
        width: preferencesView.height * 0.9
        height: parent.height * 0.8
        color: "#e4eded"
        border.width: app.ratioH * 1

        Rectangle {
            id: titleArea
            anchors.top: parent.top
            anchors.horizontalCenter: parent.horizontalCenter
            width: parent.width
            height: preferencesView.height * 0.05
            color: "white"
            border.width: app.ratioH * 1
            Rectangle {
                id: back
                anchors.top: parent.top
                anchors.bottom: parent.bottom
                anchors.left: parent.left
                width: backText.paintedWidth * 2
                color: "#00000000"
                Text {
                    id: backText
                    anchors.centerIn: parent
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                    text: qsTr("Retour")
                    color: "#0937b7"
                    font.pixelSize: userWindowLoader.fontText
                }

                MouseArea {
                    anchors.fill: parent
                    onClicked: userWindowLoader.source = "myAccount.qml"
                }
            }
            Text {
                id: title
                anchors.centerIn: parent
                text: qsTr("Mon compte")
                font.bold: true
                font.pixelSize: userWindowLoader.fontText
                color: "black"
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            }
        }
        Column {
            id: column1
            anchors.top: titleArea.bottom
            anchors.topMargin: app.ratioH * 30
            anchors.right: parent.right
            anchors.rightMargin: app.ratioH * 10
            anchors.bottom: parent.bottom
            anchors.bottomMargin: app.ratioH * 30
            anchors.left: parent.left
            anchors.leftMargin: app.ratioH * 10
            spacing: app.ratioH * 20
            Item {
                height: subTitle.height
                width: parent.width
                Text {
                    id: subTitle

                    text: qsTr("Mise à jour et téléchargement des médias")
                    font.pixelSize: userWindowLoader.fontText
                    color: "#083ab9"
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                    anchors.horizontalCenter: parent.horizontalCenter
                }
            }
            Item {
                height: findMajTxt.height
                width: parent.width
                Text {
                    id: findMajTxt
                    anchors.centerIn: parent
                    text: qsTr("Recherche les mises à jour")
                    font.bold: true
                    font.pixelSize: userWindowLoader.fontText
                    color: "#063aba"
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                    anchors.horizontalCenter: parent.horizontalCenter
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        if (vcc.online) {
                            console.log("[QML MyAccountPref] recherche MAJ")
                            app.seekUpdateData()
                        } else
                            notOnline.visible = true
                    }
                }
            }
            Row {
                id: verifRow
                spacing: app.ratioH * 5
                height: verifText.height
                width: parent.width
                Item {
                    height: verifText.height
                    width: verifSwitch.width
                    Switch {
                        id: verifSwitch
                        checked: vcc.verifAuto
                        anchors.verticalCenter: parent.verticalCenter
                    }
                    MouseArea {
                        /* define twice because Cannot anchors for items inside Row */
                        anchors.fill: parent
                        onClicked: verifSwitch.checked ? vcc.verifAuto = false : verifPopup.open()
                    }
                }
                Item {
                    height: parent.height
                    width: verifText.width
                    Text {
                        id: verifText
                        wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                        width: verifRow.width - verifSwitch.width - verifRow.spacing
                        color: "#0937b7"
                        text: qsTr(
                                  "Vérifier les mises à jour à chaque redémarrage de l'application")
                        font.pixelSize: userWindowLoader.fontText
                        anchors.verticalCenter: parent.verticalCenter
                    }
                    MouseArea {
                        /* define twice because Cannot anchors for items inside Row */
                        anchors.fill: parent
                        onClicked: verifSwitch.checked ? vcc.verifAuto = false : verifPopup.open()
                    }
                }
            }
            Row {
                id: automRow
                spacing: app.ratioH * 5
                width: parent.width
                height: automText.height
                Item {
                    height: automText.height
                    width: automSwitch.width
                    Switch {
                        id: automSwitch
                        checked: vcc.downloadAuto
                        anchors.verticalCenter: parent.verticalCenter
                    }

                    MouseArea {
                        /* define twice because Cannot anchors for items inside Row */
                        anchors.fill: parent
                        onClicked: vcc.downloadAuto ? automNoPopup.open(
                                                          ) : automPopup.open()
                    }
                }
                Item {
                    height: parent.height
                    width: automText.width
                    Text {
                        id: automText
                        color: "#0937b7"
                        wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                        width: automRow.width - automSwitch.width - automRow.spacing
                        text: qsTr("Téléchargement automatique des médias")
                        font.pixelSize: userWindowLoader.fontText
                        anchors.verticalCenter: parent.verticalCenter
                    }
                    MouseArea {
                        /* define twice because Cannot anchors for items inside Row */
                        anchors.fill: parent
                        onClicked: vcc.downloadAuto ? automNoPopup.open(
                                                          ) : automPopup.open()
                    }
                }
            }
            Item {
                id: reinit
                width: parent.width
                height: reinitText.height
                Text {
                    id: reinitText
                    anchors.centerIn: parent
                    text: qsTr("Réinitialiser")
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                    font.bold: true
                    font.pixelSize: userWindowLoader.fontText
                    color: "#0937b7"
                    anchors.horizontalCenter: parent.horizontalCenter
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        reinitPopup.open()
                    }
                }
            }
        }
    }
    MessageDialog {
        id: verifPopup
        title: qsTr("Mise à jour")
        text: qsTr("Une recherche de mise à jour sera effectuée à chaque redémarrage de l'application")
        onYes: {
            vcc.verifAuto = true
        }
        standardButtons: StandardButton.Yes | StandardButton.No
    }
    MessageDialog {
        id: automPopup
        title: qsTr("téléchargement automatique")
        text: qsTr("Le téléchargement de toutes les nouvelles animations se fera automatiquement. Confirmez-vous ce choix ?")
        onYes: {
            vcc.downloadAuto = true
        }
        standardButtons: StandardButton.Yes | StandardButton.No
    }
    MessageDialog {
        id: automNoPopup
        title: qsTr("téléchargement automatique")
        text: qsTr("Vous êtes sur le point d'arrêter le téléchargement automatique du nouveau contenu. Confirmez vous ce choix ?")
        onYes: {
            vcc.downloadAuto = false
        }
        standardButtons: StandardButton.Yes | StandardButton.No
    }
    MessageDialog {
        id: reinitPopup
        title: qsTr("Réinitialisation")
        text: qsTr("Êtes-vous sûr de vouloir supprimer tous les médias ? (vous pourrez de nouveau le télécharger quand vous le souhaiterez)")
        onYes: {
            app.reinitMedia()
        }
        standardButtons: StandardButton.Yes | StandardButton.No
    }
}
