/*
 * sendEmail.qml
 * send email window
 *
 * VCC VisualCare Consult
 *
 * Created by Yannick GRANGER, Medi-Productions
 * ygranger@mediproductions.com
 * Copyright 2014 Medi-Productions. All rights reserved
 *
 */

import QtQuick 2.7
import QtQuick.Controls 2.1
//import QtQuick.Controls.Styles 1.4
import QtQuick.Dialogs 1.2

Rectangle {
    id: emailView
    width: app.width
    height: app.height
    color: "#55000000"
    MouseArea {
        anchors.rightMargin: 0
        anchors.bottomMargin: 0
        anchors.leftMargin: 0
        anchors.topMargin: 0 //to cancel mousearea under this qml
        anchors.fill: parent
        onClicked: {
            Qt.inputMethod.hide()
        }
    }
    Rectangle {
        id: window
        anchors.centerIn: parent
        width: emailView.height * 0.9
        height: parent.height * 0.8
        color: "#e4eded"
        border.width: emailView.height * 0.002

        Rectangle {
            id: titleArea
            anchors.top: parent.top
            anchors.horizontalCenter: parent.horizontalCenter
            width: parent.width
            height: emailView.height * 0.05
            color: "#ffffff"
            border.width: emailView.height * 0.002
            Rectangle {
                id: back
                anchors.top: parent.top
                anchors.bottom: parent.bottom
                anchors.left: parent.left
                width: backText.paintedWidth * 2
                color: "#00000000"
                Text {
                    id: backText
                    anchors.centerIn: parent
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                    text: qsTr("Retour")
                    color: "#0937b7"
                    font.pixelSize: userWindowLoader.fontText
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: emailLoader.source = ""
                }
            }
            Text {
                id: title
                anchors.centerIn: parent
                text: qsTr("Partager un média")
                font.bold: true
                font.pixelSize: userWindowLoader.fontText
                color: "black"
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            }
        }

        Column {
            id: content
            width: parent.width * 0.95
            anchors.top: titleArea.bottom
            anchors.topMargin: parent.width * 0.02
            anchors.bottom: parent.bottom
            anchors.bottomMargin: parent.width * 0.02
            anchors.horizontalCenter: parent.horizontalCenter
            spacing: emailView.height * 0.02

            Row {
                id: email
                width: content.width * 0.6
                anchors.horizontalCenter: parent.horizontalCenter
                Rectangle {
                    id: emailRect
                    height: emailField.height
                    radius: emailView.height * 0.003
                    border.color: "#999"
                    border.width: emailView.height * 0.002
                    width: emailText.paintedWidth * 1.1
                    Text {
                        id: emailText
                        text: qsTr("Email *")
                        color: "#0038b6"
                        anchors.centerIn: parent
                        font.pixelSize: userWindowLoader.fontText
                    }
                }
                TextField {
                    id: emailField
                    color: "black"
                    background: Rectangle {
                        radius: app.ratioH * 2
                        border.color: "#999"
                        border.width: app.ratioH * 1
                    }
                    font.pixelSize: userWindowLoader.fontText
                    width: content.width * 0.6 - email.spacing - emailRect.width
                    placeholderText: qsTr("adresse email du destinataire")
                    inputMethodHints: Qt.ImhEmailCharactersOnly| Qt.ImhNoAutoUppercase
                    text: app.memorizedEmail
                    onTextChanged: app.writingInEmailField(text)
                    Component.onCompleted: app.writingInEmailField(text)
                }
            }

            Column {
                id: message
                width: content.width * 0.6
                spacing: emailView.height * 0.003
                anchors.horizontalCenter: parent.horizontalCenter
                Text {
                    text: qsTr("Message")
                    color: "#0038b6"
                    font.pixelSize: userWindowLoader.fontText
                }

                TextArea {
                    id: messageField
                    background:Rectangle{
                        implicitHeight: content.height * 0.4
                        implicitWidth: parent.parent.width
                        radius: app.ratioH * 2
                        border.color: "#999"
                        border.width: app.ratioH * 1
                    }
                    font.pixelSize: userWindowLoader.fontText
                }
            }

            Row {
                id: accepted
                width: content.width * 0.6
                anchors.horizontalCenter: parent.horizontalCenter
                Text {
                    id: switchText
                    text: qsTr("Le destinataire a accepté de recevoir cet email.")
                    wrapMode: Text.WordWrap
                    color: "#0038b6"
                    font.pixelSize: userWindowLoader.fontText
                    width: parent.width - enableSwitch.width
                }
                Item {
                    height: switchText.height
                    width: enableSwitch.width
                    Switch {
                        id: enableSwitch
                        checked: false
                        anchors.bottom: parent.bottom
                    }
                }
            }

            Rectangle {
                id: sendButton
                width: content.width * 0.6
                height: 50
                color: "#e4eded"
                anchors.horizontalCenter: parent.horizontalCenter
                border.width: emailView.height * 0.002
                border.color: "#0038b6"
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        if (sendButton.state == "enabled" && vcc.online) {
                            var re = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/
                            if (re.test(emailField.text)) {
                                app.memorizedEmail = emailField.text
                                app.sendEmail(emailField.text,
                                              messageField.text, app._filename,
                                              app._fileTitle)
                                emailLoader.source = ""
                            } else
                                wrongEmail.open()
                        } else if (!vcc.online)
                            notOnline.visible = true
                    }
                }
                Text {
                    id: sendText
                    text: qsTr("Envoyer")
                    font.pixelSize: userWindowLoader.fontText
                    anchors.centerIn: parent
                    color: "#0038b6"
                }

                state: enableSwitch.checked ? "enabled" : "disabled"
                states: [
                    State {
                        name: "enabled"
                        PropertyChanges {
                            target: sendButton
                            opacity: 1
                        }
                    },
                    State {
                        name: "disabled"
                        PropertyChanges {
                            target: sendButton
                            opacity: 0.2
                        }
                    }
                ]
            }
        }

        ListView {
            property int delegateHeight: 0
            id: list
            model: completionModel
            anchors.top: content.top
            anchors.topMargin: email.height
            anchors.right: content.right
            anchors.rightMargin: content.width * 0.2
            width: emailField.width
            height: (count < 6 ? count : 5.5) * delegateHeight
            clip: true
            delegate: Rectangle {
                id: proposalRect
                height: proposal.implicitHeight * 2
                width: emailField.width
                color: "#EEEEEE"
                radius: 7 * app.ratioH
                Text {
                    id: proposal
                    anchors.verticalCenter: parent.verticalCenter
                    font.pixelSize: userWindowLoader.fontText * 0.8
                    anchors.left: parent.left
                    anchors.leftMargin: parent.height / 3
                    function boldSelection(chaine) {
                        var longueur = emailField.text.length
                        var result = "<b>"
                        for (var i = 0; i < longueur; i++) {
                            result += chaine.charAt(i)
                        }
                        result += "</b>"
                        for (var j = longueur; j < chaine.length; j++) {
                            result += chaine.charAt(j)
                        }
                        return result
                    }
                    Component.onCompleted: {
                        if (emailField.text !== model.email) {
                            var chaine = ""
                            chaine = boldSelection(model.email)
                            proposal.text = chaine
                        } else {
                            /*   hide completion when typed email is complete  */
                            app.writingInEmailField("")
                        }
                        list.delegateHeight = proposal.implicitHeight * 2
                    }
                }
                MouseArea {
                    anchors.fill: proposalRect
                    onClicked: emailField.text = model.email
                }
            }
        }
    }
    MessageDialog {
        id: wrongEmail
        title: qsTr("Problème d'email")
        text: qsTr("L'adresse email n'est pas valide")
        standardButtons: StandardButton.Ok
    }
}
