
/*
 * main.qml
  * main view : toolbar and params
   *
    * VCC VisualCare Consult
     *
      * Created by Yannick GRANGER, Medi-Productions
       * ygranger@mediproductions.com
        * Copyright 2014 Medi-Productions. All rights reserved
         *
          */
import QtQuick 2.7
import QtQuick.Controls 2.1
import QtQuick.Dialogs 1.2
import "component/"

Item {
    id: app
    objectName: "app"
    width: 1024
    height: 768

    property color ribbonColor: vccContract_Short === "DWR" ? "#444444" : "#216378"
    property color ribbonColor2: "#98b4bf"
    property string currentStack: "logo.qml"
    property alias stackView: stackView
    property string _animalSelected: ""
    property string _organSelected: ""
    property var _stateSelected
    property string _skin: ""
    property string _skelFront: ""
    property string _skelBack: ""
    property string _whole1: ""
    property string _subpath: ""
    property string _filename: ""
    property string _fileTitle: ""
    property string _fileType: ""
    property string _linkedUrl: ""
    property bool _fileOk: false
    property double ratioH: height / 600
    property double ratioW: width / 1024
    property double ratio: height != 0 ? width / height : 1
    property bool mediaInFullscreen: false
    property string memorizedEmail: ""
    onHeightChanged: console.log("[QML Main] height : ", height)
    onWidthChanged: console.log("[QML Main] width : ", width)
    onRatioWChanged: console.log("[QML Main ratiow : ", ratioW)
    onRatioHChanged: console.log("[QML Main] ratioh : ", ratioH)
    onRatioChanged: console.log("[QML Main] ratio : ", ratio)

    Component.onCompleted: {
        console.log("[QML Main] width : ", width)
        console.log("[QML Main] height : ", height)
    }

    FontLoader {
        id: localFont
        source: "../fonts/DejaVuSans.ttf"
    }

    Connections {
        target: vccData
        onAnimalsUpdateChanged: {
            console.log("[QML main] on animals updated =>"+headerAnimals.length)
            customSectionButtons.model = headerAnimals
        }
    }
    signal animalSelected(string animalSubPath)
    signal organSelected(string organ)//prefer subpath to name, more generic
    signal subOrganSelected(string subOrgan)
    signal mediaBundleSelected(string mediaBundle)
    signal reinitMedia
    signal watch(string filename, string fileTitle)
    signal downloadNow(string filename, string priorityType)
    signal doLogin(string loginId, string password, string contract)
    signal getContractList(string loginId)
    signal sendEmail(string receiverEmail, string message, string filename, string fileTitle)
    signal addBookmark(string filename, string fileTitle, string fileType,  bool fromSettings)
    signal addInPlaylist(string filename, string fileTitle, string fileType, bool fromSettings)
    signal deleteStoredItem(string filename, string store)
    signal renameStoredItem(string filename, string fileTitle, string store)
    signal started
    signal displayEmailForm
    signal quit//to load new data
    signal seekUpdateData/* to quit on home button click */
    signal writingInEmailField(string writtenText)
    signal checkMd5ForFile(string filename)

    onCurrentStackChanged: {
        toolbar.updateButtonDisplay()
    }

    Keys.onBackPressed: {
        console.log("[QML main] KEY_PRESSED: back")
        if (stackView.depth > 2) {
            stackView.pop()
        } else {
            app.quit()
        }
    }
    Rectangle {
        id: appliRectangle
        anchors.fill: parent
        Rectangle {
            id: background
            anchors.fill: parent

            Image {
                fillMode: Image.Stretch
                anchors.fill: parent
                source: vccContract_Short
                        === "DWR" ? "../img/fond-ecran-dwr.jpg" : "../img/fond-ecran.jpg"
            }
        }
        state: "tallHeader"
        states: [
            State {
                name: "maxHeader"
                PropertyChanges {
                    target: header
                    anchors.rightMargin: 0
                    height: app.ratioH * 80
                }
                PropertyChanges {
                    target: borderLine
                    anchors.rightMargin: 0
                }
            },
            State {
                name: "tallHeader"
                PropertyChanges {
                    target: header
                    anchors.rightMargin: 0
                    height: app.ratioH * 200
                }
                PropertyChanges {
                    target: borderLine
                    anchors.rightMargin: 0
                }
            }
        ]

        Rectangle {
            id: header
            height: app.ratioH * 80
            color: ribbonColor
            anchors.right: parent.right
            anchors.left: parent.left
            anchors.top: parent.top
            Item {
                id: playlistButton
                anchors.verticalCenter: toolbar.verticalCenter
                anchors.left: parent.left
                anchors.leftMargin: visible ? app.ratioH * 10 : 0
                width: visible ? toolbar.height : 0
                height: visible ? toolbar.height : 0
                Image {
                    anchors.centerIn: parent
                    anchors.fill: parent
                    fillMode: Image.PreserveAspectFit
                    mipmap: canDoMipmap
                    source: "../img/icones/icone-playlist.png"
                }
                state: "on"
                states: [
                    State {
                        name: "on"
                        PropertyChanges {
                            target: playlistButton
                            opacity: 1.0
                        }
                    },
                    State {
                        name: "off"
                        PropertyChanges {
                            target: playlistButton
                            opacity: 0.5
                        }
                    }
                ]
                MouseArea {
                    anchors.fill: parent
                    onPressed: parent.state = "off"
                    onReleased: parent.state = "on"
                    onClicked: {
                        console.log("[QML Main] display playlist")
                        app._filename = ""
                        var _replace = stackView.depth > 2
                        if (_replace){
                            stackView.replace(Qt.resolvedUrl("stackView/mediaView.qml"),
                                                {
                                                   stackName: "playlist.qml" ,
                                                   title: qsTr("PLAYLIST")
                                               })
                        }else{

                            stackView.push(Qt.resolvedUrl("stackView/mediaView.qml"),
                                                {
                                                   stackName: "playlist.qml" ,
                                                   title: qsTr("PLAYLIST")
                                               })
                        }
                    }
                }
            }
            Item {
                id: bookmarksButton
                anchors.verticalCenter: toolbar.verticalCenter
                anchors.left: playlistButton.right
                anchors.leftMargin: visible ? app.ratioH * 10 : 0
                width: visible ? toolbar.height : 0
                height: visible ? toolbar.height : 0
                Image {
                    anchors.centerIn: parent
                    anchors.fill: parent
                    fillMode: Image.PreserveAspectFit
                    mipmap: canDoMipmap
                    source: "../img/icones/icone-favoris.png"
                }
                state: "on"
                states: [
                    State {
                        name: "on"
                        PropertyChanges {
                            target: bookmarksButton
                            opacity: 1.0
                        }
                    },
                    State {
                        name: "off"
                        PropertyChanges {
                            target: bookmarksButton
                            opacity: 0.5
                        }
                    }
                ]
                MouseArea {
                    anchors.fill: parent
                    onPressed: parent.state = "off"
                    onReleased: parent.state = "on"
                    onClicked: {
                        console.log("[QML Main] display bookmarks")
                        app._filename = ""
                        var _replace = stackView.depth > 2
                        if (_replace){
                            stackView.replace(Qt.resolvedUrl("stackView/mediaView.qml"),
                                                {
                                                   stackName: "bookmarks.qml" ,
                                                   title: qsTr("FAVORIS")
                                               })
                        }else{

                            stackView.push(Qt.resolvedUrl("stackView/mediaView.qml"),
                                                {
                                                   stackName: "bookmarks.qml" ,
                                                   title: qsTr("FAVORIS")
                                               })
                        }
                    }
                }
            }
            Item {
                id: receptionButton
                anchors.verticalCenter: toolbar.verticalCenter
                anchors.left: bookmarksButton.right
                anchors.leftMargin: visible ? app.ratioH * 10 : 0
                width: visible
                       && (vccContract_Short === "IDEXX"
                           || vccContract_Short === "REDBANK") ? toolbar.height : 0
                height: visible ? toolbar.height : 0
                Image {
                    anchors.centerIn: parent
                    anchors.fill: parent
                    fillMode: Image.PreserveAspectFit
                    mipmap: canDoMipmap
                    source: (vccContract_Short === "IDEXX" || vccContract_Short
                             === "REDBANK") ? "../img/icones/icone-reception.png" : ""
                }
                state: "on"
                states: [
                    State {
                        name: "on"
                        PropertyChanges {
                            target: receptionButton
                            opacity: 1.0
                        }
                    },
                    State {
                        name: "off"
                        PropertyChanges {
                            target: receptionButton
                            opacity: 0.5
                        }
                    }
                ]
                MouseArea {
                    anchors.fill: parent
                    onPressed: parent.state = "off"
                    onReleased: parent.state = "on"
                    onClicked: {
                        console.log("[QML Main] display reception")
                        app._filename = ""
                        var _replace = stackView.depth > 2
                        app.animalSelected("reception")
                        if (_replace){
                            stackView.replace(Qt.resolvedUrl("stackView/mediaView.qml"),
                                                {
                                                   stackName: "mediaView.qml",
                                                   title: qsTr("RECEPTION")
                                               })
                        }else{

                            stackView.push(Qt.resolvedUrl("stackView/mediaView.qml"),
                                                {
                                                   stackName: "mediaView.qml",
                                                   title: qsTr("RECEPTION")
                                               })
                        }
                    }
                }
            }
            Row {
                id: toolbar
                anchors.verticalCenter: parent.verticalCenter
                anchors.rightMargin: app.ratioH * 10
                anchors.leftMargin: app.ratioH * 10
                spacing: app.ratioH * 10
                height: app.ratioH * 40
                function updateButtonDisplay() {
                    console.log("[QML Main] current stack = " + app.currentStack)
                    if (app.currentStack == ""
                            || app.currentStack == "logo.qml") {
                        state = "hide"
                        parent.parent.state = "tallHeader"
                    } else if (app.currentStack == "animalSelector.qml") {
                        state = "animal"
                        parent.parent.state = "maxHeader"
                    } else if (app.currentStack == "organSelector.qml") {
                        state = "organ"
                        parent.parent.state = "maxHeader"
                    } else if (app.currentStack == "mediaView.qml") {
                        state = "media"
                        parent.parent.state = "maxHeader"
                    } else if (app.currentStack == "bookmarks.qml") {
                        state = "bookmarks"
                        parent.parent.state = "maxHeader"
                    } else if (app.currentStack == "playlist.qml") {
                        state = "playlist"
                        parent.parent.state = "maxHeader"
                    } else if (app.currentStack == "fileManager.qml") {
                        state = "file"
                        parent.parent.state = "maxHeader"
                    } else if (app.currentStack == "vca_country.qml") {
                        state = "vca_country"
                        parent.parent.state = "maxHeader"
                    }else if (app.currentStack == "vca_state.qml") {
                        state = "vca_state"
                        parent.parent.state = "maxHeader"
                    }else {
                        state = "all"
                        parent.parent.state = "maxHeader"
                    }
                }

                state: "hide"
                states: [
                    State {
                        name: "hide"
                        PropertyChanges {
                            target: toolbar
                            visible: false
                        }
                        PropertyChanges {
                            target: bookmarksButton
                            visible: false
                        }
                        PropertyChanges {
                            target: playlistButton
                            visible: false
                        }
                        PropertyChanges {
                            target: receptionButton
                            visible: false
                        }
                        PropertyChanges {
                            target: customSectionButtons
                            visible: false
                        }
                        AnchorChanges {
                            target: toolbar
                            anchors.left: undefined
                            anchors.horizontalCenter: parent.horizontalCenter
                            anchors.right: undefined
                        }
                    },
                    State {
                        name: "bookmarks"
                        PropertyChanges {
                            target: toolbar
                            visible: true
                        }
                        AnchorChanges {
                            target: toolbar
                            anchors.left: receptionButton.right
                            anchors.horizontalCenter: undefined
                            anchors.right: undefined
                        }
                        PropertyChanges {
                            target: homeButton
                            visible: true
                        }
                        PropertyChanges {
                            target: bookmarksButton
                            visible: false
                        }
                        PropertyChanges {
                            target: playlistButton
                            visible: true
                        }
                        PropertyChanges {
                            target: fileManagerButton
                            visible: false
                        }
                        PropertyChanges {
                            target: userButton
                            visible: false
                        }
                        PropertyChanges {
                            target: receptionButton
                            visible: false
                        }
                        PropertyChanges {
                            target: customSectionButtons
                            visible: customSection
                        }
                    },
                    State {
                        name: "playlist"
                        PropertyChanges {
                            target: toolbar
                            visible: true
                        }
                        AnchorChanges {
                            target: toolbar
                            anchors.left: receptionButton.right
                            anchors.horizontalCenter: undefined
                            anchors.right: undefined
                        }
                        PropertyChanges {
                            target: homeButton
                            visible: true
                        }
                        PropertyChanges {
                            target: bookmarksButton
                            visible: true
                        }
                        PropertyChanges {
                            target: playlistButton
                            visible: false
                        }
                        PropertyChanges {
                            target: fileManagerButton
                            visible: false
                        }
                        PropertyChanges {
                            target: userButton
                            visible: false
                        }
                        PropertyChanges {
                            target: receptionButton
                            visible: false
                        }
                        PropertyChanges {
                            target: customSectionButtons
                            visible: customSection
                        }
                    },
                    State {
                        name: "animal"
                        PropertyChanges {
                            target: toolbar
                            visible: true
                        }
                        AnchorChanges {
                            target: toolbar
                            anchors.left: undefined
                            anchors.horizontalCenter: undefined
                            anchors.right: parent.right
                        }
                        PropertyChanges {
                            target: homeButton
                            visible: false
                        }
                        PropertyChanges {
                            target: bookmarksButton
                            visible: vcc.connected
                        }
                        PropertyChanges {
                            target: playlistButton
                            visible: vcc.connected
                        }
                        PropertyChanges {
                            target: fileManagerButton
                            visible: vcc.connected
                        }
                        PropertyChanges {
                            target: userButton
                            visible: true
                        }
                        PropertyChanges {
                            target: receptionButton
                            visible: vcc.connected
                                     && (vccContract_Short === "IDEXX" || vccContract_Short === "REDBANK")
                        }
                        PropertyChanges {
                            target: customSectionButtons
                            visible: headerAnimals.length
                        }
                    },
                    State {
                        name: "organ"
                        PropertyChanges {
                            target: toolbar
                            visible: true
                        }
                        AnchorChanges {
                            target: toolbar
                            anchors.left: receptionButton.right
                            anchors.horizontalCenter: undefined
                            anchors.right: undefined
                        }
                        PropertyChanges {
                            target: homeButton
                            visible: true
                        }
                        PropertyChanges {
                            target: bookmarksButton
                            visible: vcc.connected
                        }
                        PropertyChanges {
                            target: playlistButton
                            visible: vcc.connected
                        }
                        PropertyChanges {
                            target: fileManagerButton
                            visible: false
                        }
                        PropertyChanges {
                            target: userButton
                            visible: false
                        }
                        PropertyChanges {
                            target: receptionButton
                            visible: false
                        }
                        PropertyChanges {
                            target: customSectionButtons
                            visible: headerAnimals.length
                        }
                    },
                    State {
                        name: "media"
                        PropertyChanges {
                            target: toolbar
                            visible: true
                        }
                        AnchorChanges {
                            target: toolbar
                            anchors.left: receptionButton.right
                            anchors.horizontalCenter: undefined
                            anchors.right: undefined
                        }
                        PropertyChanges {
                            target: homeButton
                            visible: true
                        }
                        PropertyChanges {
                            target: bookmarksButton
                            visible: vcc.connected
                        }
                        PropertyChanges {
                            target: playlistButton
                            visible: vcc.connected
                        }
                        PropertyChanges {
                            target: fileManagerButton
                            visible: false
                        }
                        PropertyChanges {
                            target: userButton
                            visible: false
                        }
                        PropertyChanges {
                            target: receptionButton
                            visible: false
                        }
                        PropertyChanges {
                            target: customSectionButtons
                            visible: headerAnimals.length //TODO && app._organSelected!=customSectionTitle
                        }
                    },
                    State {
                        name: "file"
                        PropertyChanges {
                            target: toolbar
                            visible: true
                        }
                        AnchorChanges {
                            target: toolbar
                            anchors.left: undefined
                            anchors.horizontalCenter: parent.horizontalCenter
                            anchors.right: undefined
                        }
                        PropertyChanges {
                            target: homeButton
                            visible: true
                        }
                        PropertyChanges {
                            target: bookmarksButton
                            visible: false
                        }
                        PropertyChanges {
                            target: playlistButton
                            visible: false
                        }
                        PropertyChanges {
                            target: fileManagerButton
                            visible: false
                        }
                        PropertyChanges {
                            target: userButton
                            visible: false
                        }
                        PropertyChanges {
                            target: receptionButton
                            visible: false
                        }
                        PropertyChanges {
                            target: customSectionButtons
                            visible: headerAnimals.length //TODO && app._organSelected!=customSectionTitle
                        }
                    },State {
                        name: "vca_country"
                        PropertyChanges {
                            target: toolbar
                            visible: true
                        }
                        AnchorChanges {
                            target: toolbar
                            anchors.left: undefined
                            anchors.horizontalCenter: undefined
                            anchors.right: parent.right
                        }
                        PropertyChanges {
                            target: homeButton
                            visible: true
                        }
                        PropertyChanges {
                            target: bookmarksButton
                            visible: vcc.connected
                        }
                        PropertyChanges {
                            target: playlistButton
                            visible: vcc.connected
                        }
                        PropertyChanges {
                            target: fileManagerButton
                            visible: false
                        }
                        PropertyChanges {
                            target: userButton
                            visible: vcc.connected
                        }
                        PropertyChanges {
                            target: receptionButton
                            visible: false
                        }
                        PropertyChanges {
                            target: customSectionButtons
                            visible: true
                        }
                    },State {
                        name: "vca_state"
                        PropertyChanges {
                            target: toolbar
                            visible: true
                        }
                        AnchorChanges {
                            target: toolbar
                            anchors.left: undefined
                            anchors.horizontalCenter: undefined
                            anchors.right: parent.right
                        }
                        PropertyChanges {
                            target: homeButton
                            visible: true
                        }
                        PropertyChanges {
                            target: bookmarksButton
                            visible: vcc.connected
                        }
                        PropertyChanges {
                            target: playlistButton
                            visible: vcc.connected
                        }
                        PropertyChanges {
                            target: fileManagerButton
                            visible: false
                        }
                        PropertyChanges {
                            target: userButton
                            visible: vcc.connected
                        }
                        PropertyChanges {
                            target: receptionButton
                            visible: false
                        }
                        PropertyChanges {
                            target: customSectionButtons
                            visible: true
                        }
                    },
                    State {
                        name: "all"
                        PropertyChanges {
                            target: toolbar
                            visible: true
                        }
                        AnchorChanges {
                            target: toolbar
                            anchors.left: undefined
                            anchors.horizontalCenter: parent.horizontalCenter
                            anchors.right: undefined
                        }
                        PropertyChanges {
                            target: homeButton
                            visible: true
                        }
                        PropertyChanges {
                            target: bookmarksButton
                            visible: vcc.connected
                        }
                        PropertyChanges {
                            target: playlistButton
                            visible: vcc.connected
                        }
                        PropertyChanges {
                            target: fileManagerButton
                            visible: vcc.connected
                        }
                        PropertyChanges {
                            target: userButton
                            visible: true
                        }
                        PropertyChanges {
                            target: receptionButton
                            visible: vcc.connected
                                     && (vccContract_Short === "IDEXX"
                                         || vccContract_Short === "REDBANK")
                        }
                        PropertyChanges {
                            target: customSectionButtons
                            visible: headerAnimals.length // TODO && app._organSelected!=customSectionTitle
                        }
                    }
                ]
                ListView{
                    id: customSectionButtons
                    anchors.verticalCenter: parent.verticalCenter
                    width:  visible ? toolbar.height * 1.1 * headerAnimals.length: 0
                    height: visible ? toolbar.height * 1.1 : 0
                    delegate: customSectionButton
                    orientation: ListView.Horizontal
//                    model:headerAnimals
                    onModelChanged: console.log("[QML Main] customSectionButtons model changed " + model.length + " "+ model[0].name)
                }



                Item {
                    id: homeButton
                    anchors.verticalCenter: parent.verticalCenter
                    width: visible ? parent.height * 1.2 : 0
                    height: visible ? parent.height * 1.2 : 0
                    Image {
                        anchors.centerIn: parent
                        anchors.fill: parent
                        fillMode: Image.PreserveAspectFit
                        mipmap: canDoMipmap
                        source: "../img/icones/icone-home.png"
                    }
                    state: "on"
                    states: [
                        State {
                            name: "on"
                            PropertyChanges {
                                target: homeButton
                                opacity: 1.0
                            }
                        },
                        State {
                            name: "off"
                            PropertyChanges {
                                target: homeButton
                                opacity: 0.5
                            }
                        }
                    ]
                    MouseArea {
                        anchors.fill: parent
                        onPressed: parent.state = "off"
                        onReleased: parent.state = "on"
                        onClicked: {
                            app._subpath = ""
                            app._animalSelected = ""
                            app._filename = ""
                            while (stackView.depth > 2) {
                                stackView.pop()
                            }
                        }
                    }
                }
                Item {
                    id: userButton
                    anchors.verticalCenter: parent.verticalCenter
                    width: visible ? parent.height : 0
                    height: visible ? parent.height : 0
                    Image {
                        anchors.centerIn: parent
                        anchors.fill: parent
                        fillMode: Image.PreserveAspectFit
                        mipmap: canDoMipmap
                        source: "../img/icones/icone-user.png"
                    }
                    state: "on"
                    states: [
                        State {
                            name: "on"
                            PropertyChanges {
                                target: userButton
                                opacity: 1.0
                            }
                        },
                        State {
                            name: "off"
                            PropertyChanges {
                                target: userButton
                                opacity: 0.5
                            }
                        }
                    ]
                    MouseArea {
                        anchors.fill: parent
                        onPressed: userButton.state = "off"
                        onReleased: userButton.state = "on"
                        onClicked: {
                            if (userWindowLoader.source == "")
                                userWindowLoader.source = (vcc.connected ? "form/myAccount.qml" : "form/myAccountLogin.qml")
                        }
                    }
                }
                Item {
                    id: fileManagerButton
                    anchors.verticalCenter: parent.verticalCenter
                    width: visible ? parent.height : 0
                    height: visible ? parent.height : 0
                    visible:vcc.connected
                    Image {
                        anchors.centerIn: parent
                        anchors.fill: parent
                        fillMode: Image.PreserveAspectFit
                        mipmap: canDoMipmap
                        source: "../img/icones/icone-engrenage.png"
                    }
                    state: "on"
                    states: [
                        State {
                            name: "on"
                            PropertyChanges {
                                target: fileManagerButton
                                opacity: 1.0
                            }
                        },
                        State {
                            name: "off"
                            PropertyChanges {
                                target: fileManagerButton
                                opacity: 0.5
                            }
                        }
                    ]
                    MouseArea {
                        anchors.fill: parent
                        onPressed: fileManagerButton.state = "off"
                        onReleased: fileManagerButton.state = "on"
                        onClicked: {
                            stackView.push(Qt.resolvedUrl("stackView/fileManager.qml"))
                        }
                    }
                }
            }
        }
        Rectangle {
            id: borderLine
            height: app.ratioH * 6
            color: ribbonColor2
            anchors.right: parent.right
            anchors.rightMargin: 0
            anchors.left: parent.left
            anchors.top: header.bottom
        }
        StackView {
            /* logo.qml =>  animalSelector.qml =>   organSelector.qml =>    mediaView.qml*/
            id: stackView /*                                 =>   bookmarks.qml   */
            objectName: "stackView"
            anchors.fill: parent
            initialItem: Qt.resolvedUrl("stackView/logo.qml")
        }
        Loader {
            id: userWindowLoader
            property int fontText: app.ratioH * 15
            source: ""
            Item {
                Connections {
                    target: vcc
                    ignoreUnknownSignals: true
                    onConnectedChanged: {
                        if (userWindowLoader.source == "form/myAccountLogin.qml"
                                && vcc.connected) {
                            userWindowLoader.source = "form/myAccount.qml"
                        } else
                            userWindowLoader.source = ""
                    }
                    onAlreadyConnected: alreadyLogged.open()
                    onUserNotFound: wrongLogin.open()
                    onUserWithoutOrder: noOrder.open()
                    onNotOnline: notOnline.open()
                    onObsoleteVersion: obsoleteVersion.open()
                    onNoDataAvailable: dataProblem.open()
                    onEmailSent: emailSentAlert.open()
                }
            }
        }
        NavigationPoints {
            anchors.bottom: parent.bottom
            anchors.bottomMargin: app.ratioH * 10
            pointSize: app.ratioH * 8
            visible: stackView.depth >= 3
                     && !app.mediaInFullscreen
                     && app.currentStack != "fileManager.qml"
                     && app.currentStack.indexOf('vca')== -1
            last: app.currentStack != "organSelector.qml"
            anchors.horizontalCenter: parent.horizontalCenter
        }
    }
    Text {
        id: testAlert
        anchors.left: app.left
        anchors.bottom: app.bottom
        text: vccContractSigle + " " + vccVersion+ " " + vccCustomVersionTitle
        visible: (stackView.depth < 3)
        color: ribbonColor
    }
    function var_dump(str,obj) {
       if(typeof obj == "object") {
          console.log("var_dump " + str + " Type: "+typeof(obj)+((obj.constructor) ? " Constructor: "+obj.constructor : "")+" Value: " + obj);
       } else {
          console.log("var_dump " + str + " Type: "+typeof(obj)+" Value: "+obj);
       }
    }

    Text {
        id: mediaCountText
        anchors.bottom: app.bottom
        anchors.right: app.right
        visible: (stackView.depth < 3)
        color: ribbonColor
        text: AvailableFileCount+"/"+DataFileCount
    }

    Component{
            id: customSectionButton
//        Rectangle{
//            color:"red"
        Item{
            id:rootCustomObject
            anchors.verticalCenter: parent.verticalCenter
            width: visible ? toolbar.height*1.2 : 0
            height: visible ? toolbar.height*1.2  : 0

            Image {
                anchors.centerIn: parent
                anchors.fill: parent
                fillMode: Image.PreserveAspectFit
                mipmap: canDoMipmap
                source: "../img/icones/icone-customSection-"+model.subpath+".png" //visible ? "../img/icones/icone-customSection-"+model.subpath+".png" : ""
            }
            state: "on"
            states: [
                State {
                    name: "on"
                    PropertyChanges {
                        target: rootCustomObject
                        opacity: 1.0
                    }
                },
                State {
                    name: "off"
                    PropertyChanges {
                        target: rootCustomObject
                        opacity: 0.5
                    }
                }
            ]
            MouseArea {
                anchors.fill: parent
                onPressed: parent.state = "off"
                onReleased: parent.state = "on"
                onClicked: {
                    console.log("[QML Main] display customSection",subpath)
                    app._filename = ""
                    var _replace = stackView.depth > 2
                    app._animalSelected=subpath
                    app.animalSelected(app._animalSelected)
                    app._organSelected=subpath
                    var _qml
                    if (model.subpath === "vca"){
                        _qml = "vca_country.qml"
                    }else{
                        _qml = "mediaView.qml"
                    }

                    if (_replace){
                        stackView.replace(Qt.resolvedUrl("stackView/" + _qml),
                                           {
                                               stackName: _qml,
                                               title: qsTr("Menu")
                                           }
                                       )
                    }else{
                        stackView.push(Qt.resolvedUrl("stackView/" + _qml),
                                           {
                                               stackName: _qml,
                                               title: qsTr("Menu")
                                           }
                                       )
                    }
                }
            }
        }
    }
    MessageDialog {
        id: updateNotification
        property bool newData: false
        objectName: "updateNotification"
        title: ""
        text: qsTr(
                  "une mise à jour est disponible, voulez vous relancez l'application maintenant ?")
        standardButtons: StandardButton.Yes | StandardButton.No
        onYes: {
            newData = false
            stackView.pop(null)
            Qt.inputMethod.hide()
        }
        onNewDataChanged: {
            visible = stackView.depth != 1 && newData
        }
    }
    MessageDialog {
        id: alreadyLogged
        title: ""
        text: qsTr("Vous êtes déjà connecté sur une autre tablette, veuillez au préalable vous déconnecter")
        standardButtons: StandardButton.Ok
    }
    MessageDialog {
        id: wrongLogin
        title: ""
        text: qsTr("Votre adresse email ou votre mot de passe est invalide")
        standardButtons: StandardButton.Ok
    }
    MessageDialog {
        id: noOrder
        title: ""
        text: qsTr("Aucune license n'est disponible pour cet utilisateur")
        standardButtons: StandardButton.Ok
    }
    MessageDialog {
        id: emptyContent
        title: qsTr("problème")
        text: qsTr("Vous devez saisir les champs obligatoires")
        standardButtons: StandardButton.Ok
    }
    MessageDialog {
        id: notOnline
        title: ""
        text: qsTr("Non connecté à internet")
        standardButtons: StandardButton.Ok
    }
    MessageDialog {
        id: obsoleteVersion
        objectName: "obsoleteVersion"
        title: ""
        text: qsTr("Vous devez mettre à jour votre application pour pouvoir l'utiliser.")
        standardButtons: StandardButton.Ok
        onAccepted: app.quit()
    }
    MessageDialog {
        id: connectionProblem
        title: ""
        text: qsTr("La connexion a échoué. Vérifiez l'état de votre connexion.")
        standardButtons: StandardButton.Ok
    }
    MessageDialog {
        id: dataProblem
        title: ""
        text: qsTr("Aucun contenu n'est disponible. Veuillez vous connecter à Internet pour obtenir le contenu de cette application.")
        standardButtons: StandardButton.Ok
        onAccepted: {
            app.seekUpdateData()
            stackView.pop(null)
            visible = false
        }
    }
    MessageDialog {
        id: emailSentAlert
        title: ""
        text: qsTr("L'email a été envoyé")
        standardButtons: StandardButton.Ok
        onAccepted: {
            visible = false
        }
    }
    MessageDialog {
        id: demoWarning
        objectName: "demoWarning"
        title: "Démonstrateur Axience"
        text: qsTr("Ce média n'est pas disponible dans ce démonstrateur.")
        standardButtons: StandardButton.Ok
    }

    MessageDialog{
        id:changelog
        title: qsTr("nouvelle version")
        text: "v1.2.1:\n-new section: spleen (dog and cat)\n-nouvelle section : rate(chien et chat)\n"
              +"\n"
              +"v1.2.0:\n-rename the bookmarks is possible\n-renommer les favoris est possible\n\n"
              +"-show the number of downloaded medias\n-affiche le nombre de médias téléchargés\n\n"
              +"-show the new features of this application\n-affiche les nouvelles fonctionnalités de cette application\n\n"
              +"-can check file integrity in the media player\n-l'integrité des fichiers peut être vérifiées depuis le lecteur média\n\n"
        standardButtons: StandardButton.Ok
        visible: !vcc.changelogRead
        onAccepted: {
            vcc.changelogRead = true
        }

    }

}
