/*
 * AnimalSelector.qml
 * animal selection view
 *
 * VCC VisualCare Consult
 *
 * Created by Yannick GRANGER, Medi-Productions
 * ygranger@mediproductions.com
 * Copyright 2014 Medi-Productions. All rights reserved
 *
 */

import QtQuick 2.7
import QtQuick.Dialogs 1.2

Item {
    id: animalSelectorView
    property bool launched: false
    property bool clickEnabled: true
    Component.onCompleted: {
        app.currentStack = "animalSelector.qml"
        //display connection form if not connected !
        console.log(("[QML animalSelector] component  oncompleted "))
    }

    Connections {
        target: stackView
        onBusyChanged: {
            if (!busy && !animalSelectorView.launched) {
                app.started()
                animalSelectorView.launched = true
            }
        }
    }

    onVisibleChanged: {
        if (this.visible === true) {
            clickEnabled = true
            animalSelectorView.opacity = 1
            app._filename = ""
            app._organSelected = ""
            app.currentStack = "animalSelector.qml"
        }
    }
    
    Column{
        width : parent.width
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: app.ratioH * 86 / 2
        spacing: -20 * app.ratioH
        PropertyAnimation {
            id: animalSelectorViewFadeout
            target: animalSelectorView
            property: "opacity"
            to: 0
            duration: 200
        }
        Item {
            id:listViewItem
            height: animalView.children[0].height
            width: parent.width
            ListView {
                id: animalView
                height : contentHeight
                opacity: 0
                width : listViewItem.width  * ( app.ratio > 1.45 ? 0.75 : 1)
                delegate: animalDelegate
                anchors.horizontalCenter: parent.horizontalCenter
                orientation: ListView.Horizontal
                Connections {
                    target: vccData
                    onAnimalsUpdateChanged: {
                        console.log("[QML animalSelector] on animals updated ")
                        animalView.model = mainPageAnimals
                        animalViewFadeIn.start()
                        if (!vcc.connected  && userWindowLoader.source == "")
                            userWindowLoader.source = "../form/myAccountLogin.qml"
                    }
                }
                PropertyAnimation {
                    id: animalViewFadeIn
                    target: animalView
                    property: "opacity"
                    to: 1
                    duration: 400
                }
            }
        }
        Item {
            id: vcaSectionAnimalLogo
            height: vcaSectionImage.height
            width: listViewItem.width / animalView.count * ( app.ratio > 1.45 ? 0.75 : 1)
            anchors.horizontalCenter: parent.horizontalCenter
            visible : vcaSection
            Image {
                id: vcaSectionImage
                width : parent.width
                fillMode: Image.PreserveAspectFit
                source: "../../img/animal/custom_section-vca.png"
            }
            MouseArea {
                id: vcaSectionMouseArea
                anchors.fill: vcaSectionImage
                onReleased:  {
                    app._filename = ""
                    app._animalSelected=customSectionTitle
                    app.animalSelected(app._animalSelected)
                    app._organSelected=customSectionTitle
                    clickEnabled = false
                    animalSelectorViewFadeout.start()
                    vcaSectionTimer.start()
                }
            }
            Timer {
                id: vcaSectionTimer
                interval: 250
                onTriggered: {
                    var _qml= "vca_country.qml"
                    stackView.push(Qt.resolvedUrl("" + _qml),
                                   {
                                       stackName: _qml,
                                       title: qsTr("Menu")
                                   }
                               )
                }
            }
        }
    }
    Component {
        id: animalDelegate
        Item {
            id: component
            height: image.height
            width: listViewItem.width / animalView.count * ( app.ratio > 1.45 ? 0.75 : 1)
            Image {
                id: image
                width : parent.width
                fillMode: Image.PreserveAspectFit
                source: "../../img/animal/" + subpath + ".png"
                onHeightChanged: animalView.height = height
                onStatusChanged: {
                    if (Image.Error == status){
                        source= "../../img/animal/empty.png"
                        unknownAnimalName.visible = true
                    }
                }
                Text{
                    id:unknownAnimalName
                    anchors.centerIn:parent
                    text : name
                    visible : false
                    color: "white"
                    font.pixelSize: app.ratioH * 20

                }

            }
            MouseArea {
                id: mouseArea
                anchors.fill: image
                enabled: animalSelectorView.clickEnabled
                onReleased: {
                    console.log("[QML animalSelector] click on ", name)
                    //if only one child we choose the only one automatically
                    if (hasOnlyOneChild) {
                        app.animalSelected(subpath)
                    }
                    //set value
                    app._animalSelected = subpath
                    app._skin = skin
                    app._skelFront = skelFront
                    app._skelBack = skelBack
                    app._whole1 = whole1
                    app._subpath = subpath

                    clickEnabled = false
                    animalSelectorViewFadeout.start()
                    timerPush.start()
                    //stackView.push(Qt.resolvedUrl("organSelector.qml"))
                }
            }
            Timer {
                id: timerPush
                interval: 250
                onTriggered: {
                    console.log("[QML animalSelector] hasOnlyOneChild", hasOnlyOneChild)
                    if (hasOnlyOneChild)
                        stackView.push( Qt.resolvedUrl("mediaView.qml"),
                                       {
                                               stackName: "mediaView.qml" /*, model:"subOrgans"*/,
                                               title: ""
                                           }
                                       )
                    else
                        stackView.push(Qt.resolvedUrl("organSelector.qml"))
                }
            }
        }
    }


    Image {
        id: mpLogo
        height: app.ratioH * 50
        clip: false
        fillMode: Image.PreserveAspectFit
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: partnershipLogo.top
        mipmap: canDoMipmap
        source: "../../img/logo/logo_medipro_" + vccContract_Short + ".png"
    }
    Image {
        id: vccLogo
        anchors.top: parent.top
        anchors.topMargin: (vccContract_Short === "IDEXX" || vccContract_Short
                            === "REDBANK") ? app.ratioH * 40 - height
                                            / 2 : app.ratioH * 80 - height / 2
        anchors.horizontalCenter: parent.horizontalCenter
        mipmap: canDoMipmap
        width: app.ratioH * 400
        fillMode: Image.PreserveAspectFit
        source: "../../img/logo/logo_title_" + vccContract_Short + ".png"
    }
    Image {
        id: partnershipLogo
        width: app.ratioH * 300
        height: vcc.connected && (vcc.mwiBranded
                                  || vcc.virbacBranded) ? app.ratioH * 35 : 0
        clip: false
        fillMode: Image.PreserveAspectFit
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: parent.bottom
        anchors.bottomMargin: app.ratioH * 5
        source: vcc.connected ? (vcc.mwiBranded ? "../../img/logo/partnership_mwi.png" : (vcc.virbacBranded ? "../../img/logo/partnership_virbac.png" : "")) : ""
        visible: vccContract_Short === "VCC"
    }
}
