/*
 * MediaView.qml
 * animation view
 *
 * VCC VisualCare Consult
 *
 * Created by Yannick GRANGER, Medi-Productions
 * ygranger@mediproductions.com
 * Copyright 2014 Medi-Productions. All rights reserved
 *
 */

import QtQuick 2.7

import QtMultimedia 5.8
import QtQuick.Dialogs 1.2
import QtQuick.Layouts 1.2
import QtQuick.Controls 1.4


import "../component/"

Item {
    property int stackViewIndex
    property string stackName
    property alias title: arbre.title

    id: mediaView
    width: app.width
    height: app.height
    Component.onCompleted: {
        mediaView.stackViewIndex = stackView.depth /* used to prevent multiple stackview pop () */
        app.currentStack = stackName
    }
    onVisibleChanged: {
        if (this.visible === true) {
            app.currentStack = stackName
        } else
            video.source = ""
    }
    Timer {
        interval: 400
        running: true
        repeat: false
        onTriggered: {
            if (mediaView.stackName == "bookmarks.qml") {
                arbre.model = bookmarks
            } else if (mediaView.stackName == "playlist.qml") {
                arbre.model = playlist
            } else
                app.organSelected(app._organSelected)
        }
    }

    function clearWindow() {
        //console.log("[QML MediaView]clear window")
        textAlert.visible = false
        clearSource()
        app._filename = ""
        app._fileTitle = ""
        app._linkedUrl = ""
    }
    function clearSource() {
        video.source = ""
    }

    function selectOutput(filenameStr, loopBool, fileOK) {
        textAlert.visible = false
        if (((filenameStr.indexOf(".mp4") !== -1)
             || (filenameStr.indexOf(".jpg") !== -1)) && fileOK) {
            video.source = filenameStr
            video.loop = loopBool
        } else if (!fileOK) {
            textAlert.visible = true
            console.log("[QML MediaView] file not downloaded")
        } else {
            console.log("[QML MediaView] wrong file extension")
            textAlert.visible = true
        }
    }
    Tree {
        id: arbre
        width: 0.4 * parent.width
        height: parent.height
        anchors.top: parent.top
        anchors.bottom: parent.bottom
        anchors.right: parent.right
        onNeedRefresh: {
            /* reinit mediaplayer when bookmarks or playlist updated */
            app._filename = ""
            video.source = ""
        }
    }

    Item {
        id: windowArea
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: arbre.left
        anchors.top: parent.top
        anchors.topMargin: app.ratioH * 86
    }
    PinchArea {
        id: pinchArea
        anchors.fill: videoArea
        enabled: true
        pinch.target: videoArea
        property bool __zoomed
        //true if zoomed
        property bool __pinchToZoom: false //don't pause/play if zooming

        onPinchStarted: {
            console.log("[QML MediaView] pinch started")
            __zoomed = (videoArea.state == "maximized")
        }

        onPinchUpdated: {
            //console.log("[QML MediaView] pinch updated", pinch.scale)
            if (!(__zoomed) && pinch.scale > 2 && video.source != "") {
                videoArea.state = "maximized"
                __pinchToZoom = true
            } else if (__zoomed && pinch.scale < 0.5) {
                videoArea.state = "normal"
                __pinchToZoom = true
            }
        }
        onPinchFinished: {
            console.log("[QML MediaView] pinch finished")
            __pinchToZoom = false
        }
        MouseArea {
            property int lastPosition
            id: mouseArea1
            anchors.fill: parent
            onPressed: {
                lastPosition = mouseX
            }
            onDoubleClicked: {
                console.log("[QML MediaView] double click")
                if (videoArea.state == "normal" && video.source != "") {
                    videoArea.state = "maximized"
                } else {
                    videoArea.state = "normal"
                }
            }
            onReleased: {
                if (!(parent.__pinchToZoom)) {
                    if ((mouseX - lastPosition) > app.width * 0.1) {
                        if (stackView.depth === mediaView.stackViewIndex) /* used to prevent multiple stackview pop () */
                        {
                            video.source = ""
                            stackView.pop()
                        }
                    } else {
                        console.log("[QML MediaView] mouse released")
                        if (video.playbackState == MediaPlayer.PausedState) {
                            console.log("[QML MediaView] mouse released => stop")
                            video.play()
                        } else if (video.playbackState == MediaPlayer.StoppedState) {
                            console.log("[QML MediaView] mouse released => replay")
                            video.play()
                        } else {
                            video.pause()
                            console.log("[QML MediaView] mouse released => pause")
                        }
                    }
                }
            }

            Text {
                id: textAlert
                text: qsTr("Média en cours de téléchargement")
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                visible: false
                font.pixelSize: app.ratioH * 25
            }
        }
    }

    Item {
        id: videoArea
        z: 3
        anchors.fill: windowArea
        onStateChanged: {
            /* state broken */
            if (state == "maximized") {
                anchors.fill = mediaView
            } else {
                anchors.fill = windowArea
            }
        }
        states: [
            State {
                name: "normal"
                PropertyChanges {
                    target: app
                    mediaInFullscreen: false
                }
            },
            State {
                name: "maximized"
                PropertyChanges {
                    target: app
                    mediaInFullscreen: true
                }
            }
        ]
        //        height: width*3/4
        MyMediaPlayer {
            id: video
            anchors.fill: parent
            onVideoEnded: {
                if (arbre.title === qsTr("PLAYLIST"))
                    arbre.launchNextItem()
            }
            onSourceChanged: {
                playlistImg.update()
                bookmarkImg.update()
            }
        }
    }

    Row {
        /* change anchors for ios problem */
        id: optionsRow
        visible: (app._filename.indexOf(".mp4") !== -1 || app._filename.indexOf(
                      ".jpg") !== -1)
                 && app._fileOk & videoArea.state != "maximized"
        /*
          change toolbar position function of the ratio
          */
        state: (app.ratio > 1.53  )?"bigRatio":"lowRatio"
        states: [
            State {
                name: "lowRatio"
                AnchorChanges {
                    target: optionsRow
                    anchors.left: videoArea.left
                    anchors.right: undefined
                    anchors.bottom: videoArea.bottom
                    anchors.top: undefined
                }
            },
            State {
                name: "bigRatio"
                AnchorChanges {
                    target: optionsRow
                    anchors.left: undefined
                    anchors.right: videoArea.right
                    anchors.bottom: undefined
                    anchors.top: videoArea.top
                }
            }
        ]
        height: app.ratioH * 60
        spacing: app.ratioH * 5
        z: 4
        Image {
            property string stateStr: ""
            id: playlistImg
            source: stateStr != "" ? "../../img/icones/icone-ajout-playlist-"
                                     + stateStr + ".png" : ""
            anchors.verticalCenter: parent.verticalCenter
            width: parent.height
            height: parent.height
            fillMode: Image.PreserveAspectFit
            mipmap: canDoMipmap
            visible: vcc.connected && (mediaView.title === ""
                                       || mediaView.title === qsTr("RECEPTION") )
            onVisibleChanged: update()
            function update() {
                if (app._filename.indexOf(".mp4") !== -1) {
                    stateStr = "off"
                    for (var i = 0; i < playlist.length; ++i) {
                        //console.log("[QML MediaView] listmodel",bookmarks[i].fileName)
                        if (app._filename === playlist[i].fileName) {
                            console.log("[QML MediaView]playlisted !")
                            stateStr = "on"
                            break
                        }
                    }
                } else
                    stateStr = ""
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if (vcc.online){
                        if (parent.stateStr == "on") {
                            console.log("[QML MediaView] del playlist item")
//                            parent.stateStr = "off"
                            app.deleteStoredItem(app._filename, "playlist")
                        } else if (parent.stateStr == "off") {
                            console.log("[QML MediaView] add playlist item")
                            app.addInPlaylist(app._filename, app._fileTitle,
                                              app._fileType, false)
//                            parent.stateStr = "on"
                        }
                    }else{
                        notOnline.visible=true
                    }
                }
            }
        }
        Image {
            property string stateStr: ""
            source: stateStr != "" ? "../../img/icones/icone-ajout-favoris-"
                                     + stateStr + ".png" : ""
            id: bookmarkImg
            anchors.verticalCenter: parent.verticalCenter
            width: parent.height
            height: parent.height
            fillMode: Image.PreserveAspectFit
            mipmap: canDoMipmap
            visible: vcc.connected && (mediaView.title === ""
                                       || mediaView.title === qsTr("RECEPTION"))
            onVisibleChanged: update()
            function update() {
                stateStr = "off"
                for (var i = 0; i < bookmarks.length; ++i) {
                    //console.log("[QML MediaView] listmodel",bookmarks[i].fileName)
                    if (app._filename === bookmarks[i].fileName) {
                        console.log("[QML MediaView]bookmarked !")
                        stateStr = "on"
                        break
                    }
                }
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if (vcc.online){
                        if (parent.stateStr == "off") {
                            console.log("[QML MediaView] add bookmark")
//                            parent.stateStr = "on"
                            bookmarkDialog.defaultText= app._fileTitle
                            bookmarkDialog.visible = true
                        } else if (parent.stateStr == "on") {
                            console.log("[QML MediaView] del bookmark")
                            app.deleteStoredItem(app._filename, "bookmarks")
//                            parent.stateStr = "off"
                        }
                    } else{
                        notOnline.visible=true
                    }
                }
            }
        }
        Image {
            id: emailImg
            source: "../../img/icones/icone-mail.png"
            width: parent.height * 0.8
            height: parent.height * 0.8
            anchors.bottom: parent.bottom
            fillMode: Image.PreserveAspectFit
            mipmap: canDoMipmap
            visible: vcc.connected && mediaView.title !== qsTr("PLAYLIST")
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if (emailLoader.source == "") {
                        /* if (currentOS == "ios")
                            video.source = ""*/ //TODO del if no problem
                        app.displayEmailForm()
                        /*if (vcc.online)
                            emailLoader.source = "../form/sendEmail.qml"
                        else
                            notOnline.visible = true*/
                    }
                }
            }
        }
        Image {
            id: medialinkImg
            source: "../../img/icones/icone-media-link.png"
            width: parent.height * 0.8
            height: parent.height * 0.8
            anchors.bottom: parent.bottom
            fillMode: Image.PreserveAspectFit
            mipmap: canDoMipmap
            visible: app._linkedUrl !== ""
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    console.log("[QML mediaView] open link ", app._linkedUrl)
                    Qt.openUrlExternally(app._linkedUrl)
                }
            }
        }
    }
    Loader {
        z: 4
        id: emailLoader
        objectName:"emailLoader"
        source: ""
    }
    MessageDialog {
        id: notFreeContent
        title: ""
        text: vcc.connected ? qsTr("Le contenu que vous souhaitez consulter n'est pas gratuit, vous devez souscrire un abonnement spécifique pour y avoir accès. Visitez notre site Web pour plus d'informations.") : qsTr(
                                  "Le contenu que vous souhaitez consulter n'est pas gratuit, vous devez vous identifier pour y avoir accés, pour cela retournez au menu principal de l'application et sélectionnez  le bouton \"Mon compte\"")
        standardButtons: StandardButton.Ok
    }
    Connections {
        target: vcc
        onBookmarksCountChanged: {
            bookmarkImg.update()
            playlistImg.update()
        }
    }

    Dialog {
        id:bookmarkDialog
        property string defaultText: "..."
        title: qsTr("nom du favoris")
        onAccepted:   {
            app.addBookmark(app._filename, bookmarkName.text,
                            app._fileType, false)
        }
        standardButtons: StandardButton.Ok
        ColumnLayout {
            id: column
            TextField {
                id: bookmarkName
                Layout.preferredWidth: app.width *0.5
                text: bookmarkDialog.defaultText
            }

        }
    }
}
