/*
 * OrganSelector.qml
 * pathview of all organs
 *
 * VCC VisualCare Consult
 *
 * Created by Yannick GRANGER, Medi-Productions
 * ygranger@mediproductions.com
 * Copyright 2014 Medi-Productions. All rights reserved
 *
 */

import QtQuick 2.7
import "../component/"

Rectangle {
    property int stackViewIndex
    property bool launched: false
    property bool clickEnabled: true
    id: fullWindow
    color: "#00FFFFFF"
    Component.onCompleted: {
        fullWindow.stackViewIndex = stackView.depth /* used to prevent multiple stackview pop () */
        app.currentStack = "organSelector.qml"
    }
    Connections {
        target: stackView
        onBusyChanged: {
            if (!busy && !fullWindow.launched) {
                timerLoad.start()
                //app.animalSelected(app._animalSelected)
                fullWindow.launched = true
            }
        }
    }
    Timer {
        id: timerLoad
        interval: 200
        onTriggered: {
            app.animalSelected(app._animalSelected)
        }
    }

    onVisibleChanged: {
        if (this.visible === true) {
            clickEnabled = true
            fullWindow.opacity = 1
            app._filename = ""
            app._organSelected = ""
            app.currentStack = "organSelector.qml"
        }
    }

    Component {
        /* component for pathview icons */
        id: delegateOrgan
        Item {
            id: component
            height: app.ratioH * 90
            width: app.ratioH * 90
            scale: PathView.iconScale
            Image {
                id: imagePicto
                width: parent.width
                height: parent.height
                anchors.horizontalCenter: component.horizontalCenter
                anchors.verticalCenter: component.verticalCenter
                source: "../../img/organs/icones/" + picto
                onStatusChanged: {
                    if (Image.Error == status){
                        source= "../../img/organs/icones/empty.png"
                        unknownOrganName.visible = true
                    }
                }
                Text{
                    id:unknownOrganName
                    anchors.centerIn:parent
                    text : name
                    visible : false
                    color: "white"
                    font.pixelSize: app.ratioH * 8

                }
            }
            MouseArea {
                anchors.fill: imagePicto
                enabled: fullWindow.clickEnabled
                onClicked: {
                    //console.log("[QML OrganSelector] click current index",organs[view.currentIndex].name,name)
                    if (view.currentIndex != index)
                        view.currentIndex = index
                    app._organSelected = name
                    animalAnim1.setOrgan(glowimg, img)
                    if (component.PathView.isCurrentItem || view.count <7) {
                        clickEnabled = false
                        firstTimerPush.interval= (view.count <7 ? 200 : 0)
                        firstTimerPush.start()
                        //stackView.push({item : Qt.resolvedUrl("mediaView.qml"), properties: {stackName:"mediaView.qml"/*, model:"subOrgans"*/, title:""}})
                    }
                }
            }
        }
    }

    Component {
        /* component for mouseArea inside and outside pathview */
        id: dragMouseArea
        MouseArea {
            property int lastPosition
            enabled: fullWindow.clickEnabled
            onClicked: {
                console.log("[QML OrganSelector] clicked !")
            }
            onPressed: lastPosition = mouseX
            onReleased: {
                if ((lastPosition - mouseX) > app.width * 0.1) {
                    clickEnabled = false
                    app._organSelected = organs[view.currentIndex].name
                    firstTimerPush.interval= (view.count <7 ? 200 : 0)
                    firstTimerPush.start()
                } else if ((mouseX - lastPosition) > app.width * 0.1) {
                    stackView.pop()
                }
            }
        }
    }
    Timer {
        id: firstTimerPush
        interval: 200
        onTriggered: {
            organSelectorViewFadeout.start()
            timerPush.start()
        }
    }
    PropertyAnimation {
        id: organSelectorViewFadeout
        target: fullWindow
        property: "opacity"
        to: 0
        duration: 200
    }
    Timer {
        id: timerPush
        interval: 250
        onTriggered: {
            stackView.push( Qt.resolvedUrl("mediaView.qml"),
                {
                   stackName: "mediaView.qml" /*, model:"subOrgans"*/,
                   title: ""
               }
           )
        }
    }

    Loader {
        sourceComponent: dragMouseArea
        anchors.fill: parent
        anchors.topMargin: app.ratioH * 80
    }
    Item {
        id: viewItem
        Connections {
            target: vccData
            onOrganUpdateChanged: {
                view.model = organs
                viewItemFadeIn.start()
            }
        }
        PropertyAnimation {
            id: viewItemFadeIn
            target: viewItem
            property: "opacity"
            to: 1
            duration: 400
        }
        anchors.verticalCenter: parent.verticalCenter
        anchors.right: parent.right
        anchors.rightMargin: height * 0.25
        height: parent.height * 0.9
        width: height * 0.5
        clip: false
        opacity: 0
        PathView {
            id: view
            anchors.top: parent.top
            anchors.left: parent.left
            height: parent.height
            width: parent.width * 2
            delegate: delegateOrgan
            path: EllipseAnti {
                width: view.width
                height: view.height
                count: view.count
                nbInCount: 7
            }
            onMovementEnded: {
                console.log("[QML OrganSelector] mvt ended current index",
                            organs[currentIndex].name)
                animalAnim1.setOrgan(organs[currentIndex].glowimg,
                                     organs[currentIndex].img)
            }
            Loader {
                sourceComponent: dragMouseArea
                anchors.fill: parent
                anchors.topMargin: app.ratioH * 80
            }
        }

        Text {
            id: textOrgan
            text: organs[view.currentIndex].name.replace("/ ", "\n")
            anchors.left: viewItem.left
            anchors.leftMargin: app.ratioH * 60
            anchors.verticalCenter: parent.verticalCenter
            style: Text.Normal
            font.italic: false
            font.bold: true
            verticalAlignment: Text.AlignVCenter
            font.pixelSize: app.ratioH * 15
            color: ribbonColor
        }
    }

    Item {
        anchors.bottom: parent.bottom
        anchors.bottomMargin: fullWindow.height * 0.07
        anchors.left: parent.left
        anchors.leftMargin: fullWindow.height * 0.05
        width: fullWindow.height * 0.75 * app.ratio / 1.6 * app.ratio / 1.6
        height: fullWindow.height * 0.75
        AnimalAnim {
            id: animalAnim1
            anchors.fill: parent
            anchors.centerIn: parent
        }
    }
}
